% Auto-generated chapter 24 for bukhari
% Hadiths in this chapter: 112

\hadithdefcmd{bukhari}{1395}{حَدَّثَنَا أَبُو عَاصِمٍ الضَّحَّاكُ بْنُ مَخْلَدٍ، عَنْ زَكَرِيَّاءَ بْنِ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ مُعَاذًا ـ رضى الله عنه ـ إِلَى الْيَمَنِ فَقَالَ ‏ "‏ ادْعُهُمْ إِلَى شَهَادَةِ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَنِّي رَسُولُ اللَّهِ، فَإِنْ هُمْ أَطَاعُوا لِذَلِكَ فَأَعْلِمْهُمْ أَنَّ اللَّهَ قَدِ افْتَرَضَ عَلَيْهِمْ خَمْسَ صَلَوَاتٍ فِي كُلِّ يَوْمٍ وَلَيْلَةٍ، فَإِنْ هُمْ أَطَاعُوا لِذَلِكَ فَأَعْلِمْهُمْ أَنَّ اللَّهَ افْتَرَضَ عَلَيْهِمْ صَدَقَةً فِي أَمْوَالِهِمْ، تُؤْخَذُ مِنْ أَغْنِيَائِهِمْ وَتُرَدُّ عَلَى فُقَرَائِهِمْ ‏"‏‏.‏\hadithno{1395}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) sent Mu`adh to Yemen and said, "Invite the people to testify that none has the right to be worshipped but Allah and I am Allah's Messenger (ﷺ), and if they obey you to do so, then teach them that Allah has enjoined on them five prayers in every day and night (in twenty-four hours), and if they obey you to do so, then teach them that Allah has made it obligatory for them to pay the Zakat from their property and it is to be taken from the wealthy among them and given to the poor}}
\hadithdefcmd{bukhari}{1396}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنِ ابْنِ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِي أَيُّوبَ، رضى الله عنه أَنَّ رَجُلاً، قَالَ لِلنَّبِيِّ صلى الله عليه وسلم أَخْبِرْنِي بِعَمَلٍ يُدْخِلُنِي الْجَنَّةَ‏.‏ قَالَ مَا لَهُ مَا لَهُ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَرَبٌ مَالَهُ، تَعْبُدُ اللَّهَ، وَلاَ تُشْرِكُ بِهِ شَيْئًا، وَتُقِيمُ الصَّلاَةَ، وَتُؤْتِي الزَّكَاةَ، وَتَصِلُ الرَّحِمَ ‏"‏‏.‏ وَقَالَ بَهْزٌ حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ، وَأَبُوهُ، عُثْمَانُ بْنُ عَبْدِ اللَّهِ أَنَّهُمَا سَمِعَا مُوسَى بْنَ طَلْحَةَ، عَنْ أَبِي أَيُّوبَ، بِهَذَا‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ أَخْشَى أَنْ يَكُونَ، مُحَمَّدٌ غَيْرَ مَحْفُوظٍ إِنَّمَا هُوَ عَمْرٌو‏.‏\hadithno{1396}\hadithtrans{Narrated Abu Aiyub:A man said to the Prophet (ﷺ) "Tell me of such a deed as will make me enter Paradise." The people said, "What is the matter with him? What is the matter with him?" The Prophet (ﷺ) said, "He has something to ask. (What he needs greatly) The Prophet (ﷺ) said: (In order to enter Paradise) you should worship Allah and do not ascribe any partners to Him, offer prayer perfectly, pay the Zakat and keep good relations with your Kith and kin." (See Hadith No. 12, Vol)}}
\hadithdefcmd{bukhari}{1397}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ يَحْيَى بْنِ سَعِيدِ بْنِ حَيَّانَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ أَعْرَابِيًّا، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ دُلَّنِي عَلَى عَمَلٍ إِذَا عَمِلْتُهُ دَخَلْتُ الْجَنَّةَ‏.‏ قَالَ ‏"‏ تَعْبُدُ اللَّهَ لاَ تُشْرِكُ بِهِ شَيْئًا، وَتُقِيمُ الصَّلاَةَ الْمَكْتُوبَةَ، وَتُؤَدِّي الزَّكَاةَ الْمَفْرُوضَةَ، وَتَصُومُ رَمَضَانَ ‏"‏‏.‏ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ لاَ أَزِيدُ عَلَى هَذَا‏.‏ فَلَمَّا وَلَّى قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ سَرَّهُ أَنْ يَنْظُرَ إِلَى رَجُلٍ مِنْ أَهْلِ الْجَنَّةِ فَلْيَنْظُرْ إِلَى هَذَا ‏"‏‏.‏ حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنْ أَبِي حَيَّانَ، قَالَ أَخْبَرَنِي أَبُو زُرْعَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا‏.‏\hadithno{1397}\hadithtrans{Narrated Abu Huraira:A Bedouin came to the Prophet (ﷺ) and said, "Tell me of such a deed as will make me enter Paradise, if I do it." The Prophet (ﷺ) said, "Worship Allah, and worship none along with Him, offer the (five) prescribed compulsory prayers perfectly, pay the compulsory Zakat, and fast the month of Ramadan." The Bedouin said, "By Him, in Whose Hands my life is, I will not do more than this." When he (the Bedouin) left, the Prophet (ﷺ) said, "Whoever likes to see a man of Paradise, then he may look at this man." Narrated Abu Zur'a: From the Prophet (ﷺ) the same as above}}
\hadithdefcmd{bukhari}{1398}{حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَبُو جَمْرَةَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ قَدِمَ وَفْدُ عَبْدِ الْقَيْسِ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّ هَذَا الْحَىَّ مِنْ رَبِيعَةَ قَدْ حَالَتْ بَيْنَنَا وَبَيْنَكَ كُفَّارُ مُضَرَ، وَلَسْنَا نَخْلُصُ إِلَيْكَ إِلاَّ فِي الشَّهْرِ الْحَرَامِ، فَمُرْنَا بِشَىْءٍ نَأْخُذُهُ عَنْكَ، وَنَدْعُو إِلَيْهِ مَنْ وَرَاءَنَا‏.‏ قَالَ ‏"‏ آمُرُكُمْ بِأَرْبَعٍ، وَأَنْهَاكُمْ عَنْ أَرْبَعٍ الإِيمَانِ بِاللَّهِ وَشَهَادَةِ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ـ وَعَقَدَ بِيَدِهِ هَكَذَا ـ وَإِقَامِ الصَّلاَةِ، وَإِيتَاءِ الزَّكَاةِ، وَأَنْ تُؤَدُّوا خُمُسَ مَا غَنِمْتُمْ، وَأَنْهَاكُمْ عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالنَّقِيرِ وَالْمُزَفَّتِ ‏"‏‏.‏ وَقَالَ سُلَيْمَانُ وَأَبُو النُّعْمَانِ عَنْ حَمَّادٍ ‏"‏ الإِيمَانِ بِاللَّهِ شَهَادَةِ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏‏.‏\hadithno{1398}\hadithtrans{Narrated Ibn `Abbas:A delegation of the tribe of `Abdul Qais came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! We are from the tribe of Rabi`a, and the infidels of the tribe of Mudar stand between us and you; so we cannot come to you except during the Sacred Months. Please order us to do something (religious deeds) which we may carry out and also invite to it our people whom we have left behind." The Prophet said, "I order you to do four things and forbid you four others: (I order you) to have faith in Allah, and confess that none has the right to be worshipped but Allah, (and the Prophet (ﷺ) gestured with his hand like this (i.e. one knot) and to offer prayers perfectly and to pay the Zakat, and to pay one-fifth of the booty in Allah's Cause. And I forbid you to use Dubba', Hantam, Naqir and Muzaffat (all these are the names of utensils used for preparing alcoholic drinks)}}
\hadithdefcmd{bukhari}{1400}{حَدَّثَنَا أَبُو الْيَمَانِ الْحَكَمُ بْنُ نَافِعٍ، أَخْبَرَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ أَبُو بَكْرٍ ـ رضى الله عنه ـ وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ فَقَالَ عُمَرُ ـ رضى الله عنه كَيْفَ تُقَاتِلُ النَّاسَ، وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ فَمَنْ قَالَهَا فَقَدْ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ إِلاَّ بِحَقِّهِ، وَحِسَابُهُ عَلَى اللَّهِ ‏"‏‏.‏ فَقَالَ وَاللَّهِ لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ، فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ، وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا كَانُوا يُؤَدُّونَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهَا‏.‏ قَالَ عُمَرُ ـ رضى الله عنه ـ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ قَدْ شَرَحَ اللَّهُ صَدْرَ أَبِي بَكْرٍ ـ رضى الله عنه ـ فَعَرَفْتُ أَنَّهُ الْحَقُّ‏.‏\hadithno{1400}\hadithtrans{Narrated Abu Huraira:When Allah's Messenger (ﷺ) died and Abu Bakr became the caliph some Arabs renegade (reverted to disbelief) (Abu Bakr decided to declare war against them), `Umar, said to Abu Bakr, "How can you fight with these people although Allah's Messenger (ﷺ) said, 'I have been ordered (by Allah) to fight the people till they say: "None has the right to be worshipped but Allah, and whoever said it then he will save his life and property from me except on trespassing the law (rights and conditions for which he will be punished justly), and his accounts will be with Allah.' " Abu Bakr said, "By Allah! I will fight those who differentiate between the prayer and the Zakat as Zakat is the compulsory right to be taken from the property (according to Allah's orders) By Allah! If they refuse to pay me even a she-kid which they used to pay at the time of Allah's Messenger (ﷺ) . I would fight with them for withholding it" Then `Umar said, "By Allah, it was nothing, but Allah opened Abu Bakr's chest towards the decision (to fight) and I came to know that his decision was right}}
\hadithdefcmd{bukhari}{1401}{حَدَّثَنَا ابْنُ نُمَيْرٍ، قَالَ حَدَّثَنِي أَبِي، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، قَالَ قَالَ جَرِيرُ بْنُ عَبْدِ اللَّهِ بَايَعْتُ النَّبِيَّ صلى الله عليه وسلم عَلَى إِقَامِ الصَّلاَةِ، وَإِيتَاءِ الزَّكَاةِ، وَالنُّصْحِ لِكُلِّ مُسْلِمٍ‏.‏\hadithno{1401}\hadithtrans{Narrated Jarir bin `Abdullah:I gave the pledge of allegiance to the Prophet (ﷺ) for offering prayer perfectly, giving Zakat, and giving good advice to every Muslim}}
\hadithdefcmd{bukhari}{1402}{حَدَّثَنَا الْحَكَمُ بْنُ نَافِعٍ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ هُرْمُزَ الأَعْرَجَ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَأْتِي الإِبِلُ عَلَى صَاحِبِهَا، عَلَى خَيْرِ مَا كَانَتْ، إِذَا هُوَ لَمْ يُعْطِ فِيهَا حَقَّهَا، تَطَؤُهُ بِأَخْفَافِهَا، وَتَأْتِي الْغَنَمُ عَلَى صَاحِبِهَا عَلَى خَيْرِ مَا كَانَتْ، إِذَا لَمْ يُعْطِ فِيهَا حَقَّهَا، تَطَؤُهُ بِأَظْلاَفِهَا، وَتَنْطَحُهُ بِقُرُونِهَا ‏"‏‏.‏ وَقَالَ ‏"‏ وَمِنْ حَقِّهَا أَنْ تُحْلَبَ عَلَى الْمَاءِ ‏"‏‏.‏ قَالَ ‏"‏ وَلاَ يَأْتِي أَحَدُكُمْ يَوْمَ الْقِيَامَةِ بِشَاةٍ يَحْمِلُهَا عَلَى رَقَبَتِهِ لَهَا يُعَارٌ، فَيَقُولُ يَا مُحَمَّدُ‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا قَدْ بَلَّغْتُ‏.‏ وَلاَ يَأْتِي بِبَعِيرٍ، يَحْمِلُهُ عَلَى رَقَبَتِهِ لَهُ رُغَاءٌ، فَيَقُولُ يَا مُحَمَّدُ‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا قَدْ بَلَّغْتُ ‏"‏‏.‏\hadithno{1402}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "(On the Day of Resurrection) camels will come to their owner in the best state of health they have ever had (in the world), and if he had not paid their Zakat (in the world) then they would tread him with their feet; and similarly, sheep will come to their owner in the best state of health they have ever had in the world, and if he had not paid their Zakat, then they would tread him with their hooves and would butt him with their horns." The Prophet (ﷺ) added, "One of their rights is that they should be milked while water is kept in front of them." The Prophet (ﷺ) added, "I do not want anyone of you to come to me on the Day of Resurrection, carrying over his neck a sheep that will be bleating. Such a person will (then) say, 'O Muhammad! (please intercede for me,) I will say to him. 'I can't help you, for I conveyed Allah's Message to you.' Similarly, I do not want anyone of you to come to me carrying over his neck a camel that will be grunting. Such a person (then) will say "O Muhammad! (please intercede for me)." I will say to him, "I can't help you for I conveyed Allah's message to you}}
\hadithdefcmd{bukhari}{1403}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِيهِ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ آتَاهُ اللَّهُ مَالاً، فَلَمْ يُؤَدِّ زَكَاتَهُ مُثِّلَ لَهُ يَوْمَ الْقِيَامَةِ شُجَاعًا أَقْرَعَ، لَهُ زَبِيبَتَانِ، يُطَوَّقُهُ يَوْمَ الْقِيَامَةِ، ثُمَّ يَأْخُذُ بِلِهْزِمَتَيْهِ ـ يَعْنِي شِدْقَيْهِ ـ ثُمَّ يَقُولُ أَنَا مَالُكَ، أَنَا كَنْزُكَ ‏"‏ ثُمَّ تَلاَ ‏\{‏لاَ يَحْسِبَنَّ الَّذِينَ يَبْخَلُونَ‏\}‏ الآيَةَ‏.‏\hadithno{1403}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever is made wealthy by Allah and does not pay the Zakat of his wealth, then on the Day of Resurrection his wealth will be made like a baldheaded poisonous male snake with two black spots over the eyes. The snake will encircle his neck and bite his cheeks and say, 'I am your wealth, I am your treasure.' " Then the Prophet (ﷺ) recited the holy verses:-- 'Let not those who withhold . . .' (to the end of the verse)}}
\hadithdefcmd{bukhari}{1404}{وَقَالَ أَحْمَدُ بْنُ شَبِيبِ بْنِ سَعِيدٍ حَدَّثَنَا أَبِي، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ خَالِدِ بْنِ أَسْلَمَ، قَالَ خَرَجْنَا مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ فَقَالَ أَعْرَابِيٌّ أَخْبِرْنِي قَوْلَ اللَّهِ، ‏\{‏وَالَّذِينَ يَكْنِزُونَ الذَّهَبَ وَالْفِضَّةَ وَلاَ يُنْفِقُونَهَا فِي سَبِيلِ اللَّهِ‏\}‏ قَالَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ مَنْ كَنَزَهَا فَلَمْ يُؤَدِّ زَكَاتَهَا فَوَيْلٌ لَهُ، إِنَّمَا كَانَ هَذَا قَبْلَ أَنْ تُنْزَلَ الزَّكَاةُ فَلَمَّا أُنْزِلَتْ جَعَلَهَا اللَّهُ طُهْرًا لِلأَمْوَالِ‏.‏\hadithno{1404}\hadithtrans{Narrated Khalid bin Aslam:We went out with 'Abdullah bin 'Umar and a bedouin said (to 'Abdullah), "Tell me about Allah's saying: "And those who hoard up gold and silver (Al-Kanz - money, gold, silver etc., the Zakat of which has not been paid) and spend it not in the Way of Allah (V.9:34)." Ibn 'Umar said, "Whoever hoarded them and did not pay the Zakat thereof, then woe to him. But these holy Verses were revealed before the Verses of Zakat. So when the Verses of Zakat were revealed, Allah made Zakat a purifier of the property}}
\hadithdefcmd{bukhari}{1405}{حَدَّثَنَا إِسْحَاقُ بْنُ يَزِيدَ، أَخْبَرَنَا شُعَيْبُ بْنُ إِسْحَاقَ، قَالَ الأَوْزَاعِيُّ أَخْبَرَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، أَنَّ عَمْرَو بْنَ يَحْيَى بْنِ عُمَارَةَ، أَخْبَرَهُ عَنْ أَبِيهِ، يَحْيَى بْنِ عُمَارَةَ بْنِ أَبِي الْحَسَنِ أَنَّهُ سَمِعَ أَبَا سَعِيدٍ ـ رضى الله عنه ـ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ، وَلَيْسَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ، وَلَيْسَ فِيمَا دُونَ خَمْسِ أَوْسُقٍ صَدَقَةٌ ‏"‏‏.‏\hadithno{1405}\hadithtrans{Narrated Abu Sa`id:Allah's Messenger (ﷺ) said, "No Zakat is due on property mounting to less than five Uqiyas (of silver), and no Zakat is due on less than five camels, and there is no Zakat on less than five Wasqs." (A Wasqs equals 60 Sa's) \& (1 Sa=3 K gms App)}}
\hadithdefcmd{bukhari}{1406}{حَدَّثَنَا عَلِيٌّ، سَمِعَ هُشَيْمًا، أَخْبَرَنَا حُصَيْنٌ، عَنْ زَيْدِ بْنِ وَهْبٍ، قَالَ مَرَرْتُ بِالرَّبَذَةِ فَإِذَا أَنَا بِأَبِي، ذَرٍّ ـ رضى الله عنه ـ فَقُلْتُ لَهُ مَا أَنْزَلَكَ مَنْزِلَكَ هَذَا قَالَ كُنْتُ بِالشَّأْمِ، فَاخْتَلَفْتُ أَنَا وَمُعَاوِيَةُ فِي الَّذِينَ يَكْنِزُونَ الذَّهَبَ وَالْفِضَّةَ وَلاَ يُنْفِقُونَهَا فِي سَبِيلِ اللَّهِ‏.‏ قَالَ مُعَاوِيَةُ نَزَلَتْ فِي أَهْلِ الْكِتَابِ‏.‏ فَقُلْتُ نَزَلَتْ فِينَا وَفِيهِمْ‏.‏ فَكَانَ بَيْنِي وَبَيْنَهُ فِي ذَاكَ، وَكَتَبَ إِلَى عُثْمَانَ ـ رضى الله عنه ـ يَشْكُونِي، فَكَتَبَ إِلَىَّ عُثْمَانُ أَنِ اقْدَمِ الْمَدِينَةَ‏.‏ فَقَدِمْتُهَا فَكَثُرَ عَلَىَّ النَّاسُ حَتَّى كَأَنَّهُمْ لَمْ يَرَوْنِي قَبْلَ ذَلِكَ، فَذَكَرْتُ ذَاكَ لِعُثْمَانَ فَقَالَ لِي إِنْ شِئْتَ تَنَحَّيْتَ فَكُنْتَ قَرِيبًا‏.‏ فَذَاكَ الَّذِي أَنْزَلَنِي هَذَا الْمَنْزِلَ، وَلَوْ أَمَّرُوا عَلَىَّ حَبَشِيًّا لَسَمِعْتُ وَأَطَعْتُ‏.‏\hadithno{1406}\hadithtrans{Narrated Zaid bin Wahab:I passed by a place called Ar-Rabadha and by chance I met Abu Dhar and asked him, "What has brought you to this place?" He said, "I was in Sham and differed with Muawiya on the meaning of (the following verses of the Qur'an): 'They who hoard up gold and silver and spend them not in the way of Allah.' (9.34). Muawiya said, 'This verse is revealed regarding the people of the scriptures." I said, It was revealed regarding us and also the people of the scriptures." So we had a quarrel and Mu'awiya sent a complaint against me to `Uthman. `Uthman wrote to me to come to Medina, and I came to Medina. Many people came to me as if they had not seen me before. So I told this to `Uthman who said to me, "You may depart and live nearby if you wish." That was the reason for my being here for even if an Ethiopian had been nominated as my ruler, I would have obeyed him}}
\hadithdefcmd{bukhari}{1408}{حَدَّثَنَا عَيَّاشٌ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ أَبِي الْعَلاَءِ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، قَالَ جَلَسْتُ‏.‏ وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، قَالَ حَدَّثَنِي أَبِي، حَدَّثَنَا الْجُرَيْرِيُّ، حَدَّثَنَا أَبُو الْعَلاَءِ بْنُ الشِّخِّيرِ، أَنَّ الأَحْنَفَ بْنَ قَيْسٍ، حَدَّثَهُمْ قَالَ جَلَسْتُ إِلَى مَلإٍ مِنْ قُرَيْشٍ، فَجَاءَ رَجُلٌ خَشِنُ الشَّعَرِ وَالثِّيَابِ وَالْهَيْئَةِ حَتَّى قَامَ عَلَيْهِمْ فَسَلَّمَ ثُمَّ قَالَ بَشِّرِ الْكَانِزِينَ بِرَضْفٍ يُحْمَى عَلَيْهِ فِي نَارِ جَهَنَّمَ، ثُمَّ يُوضَعُ عَلَى حَلَمَةِ ثَدْىِ أَحَدِهِمْ حَتَّى يَخْرُجَ مِنْ نُغْضِ كَتِفِهِ، وَيُوضَعُ عَلَى نُغْضِ كَتِفِهِ حَتَّى يَخْرُجَ مِنْ حَلَمَةِ ثَدْيِهِ يَتَزَلْزَلُ، ثُمَّ وَلَّى فَجَلَسَ إِلَى سَارِيَةٍ، وَتَبِعْتُهُ وَجَلَسْتُ إِلَيْهِ، وَأَنَا لاَ أَدْرِي مَنْ هُوَ فَقُلْتُ لَهُ لاَ أُرَى الْقَوْمَ إِلاَّ قَدْ كَرِهُوا الَّذِي قُلْتَ‏.‏ قَالَ إِنَّهُمْ لاَ يَعْقِلُونَ شَيْئًا‏.‏ قَالَ لِي خَلِيلِي ـ قَالَ قُلْتُ مَنْ خَلِيلُكَ قَالَ النَّبِيُّ صلى الله عليه وسلم ـ ‏"‏ يَا أَبَا ذَرٍّ أَتُبْصِرُ أُحُدًا ‏"‏‏.‏ قَالَ فَنَظَرْتُ إِلَى الشَّمْسِ مَا بَقِيَ مِنَ النَّهَارِ وَأَنَا أُرَى أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يُرْسِلُنِي فِي حَاجَةٍ لَهُ، قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ مَا أُحِبُّ أَنَّ لِي مِثْلَ أُحُدٍ ذَهَبًا أُنْفِقُهُ كُلَّهُ إِلاَّ ثَلاَثَةَ دَنَانِيرَ ‏"‏‏.‏ وَإِنَّ هَؤُلاَءِ لاَ يَعْقِلُونَ، إِنَّمَا يَجْمَعُونَ الدُّنْيَا‏.‏ لاَ وَاللَّهِ لاَ أَسْأَلُهُمْ دُنْيَا، وَلاَ أَسْتَفْتِيهِمْ عَنْ دِينٍ حَتَّى أَلْقَى اللَّهَ‏.‏\hadithno{1408}\hadithtrans{Narrated Al-Ahnaf bin Qais:While I was sitting with some people from Quraish, a man with very rough hair, clothes, and appearance came and stood in front of us, greeted us and said, "Inform those who hoard wealth, that a stone will be heated in the Hell-fire and will be put on the nipples of their breasts till it comes out from the bones of their shoulders and then put on the bones of their shoulders till it comes through the nipples of their breasts the stone will be moving and hitting." After saying that, the person retreated and sat by the side of the pillar, I followed him and sat beside him, and I did not know who he was. I said to him, "I think the people disliked what you had said." He said, "These people do not understand anything, although my friend told me." I asked, "Who is your friend?" He said, "The Prophet (ﷺ) said (to me), 'O Abu Dhar! Do you see the mountain of Uhud?' And on that I (Abu Dhar) started looking towards the sun to judge how much remained of the day as I thought that Allah's Messenger (ﷺ) wanted to send me to do something for him and I said, 'Yes!' He said, 'I do not love to have gold equal to the mountain of Uhud unless I spend it all (in Allah's cause) except three Dinars (pounds). These people do not understand and collect worldly wealth. No, by Allah, Neither I ask them for worldly benefits nor am I in need of their religious advice till I meet Allah, The Honorable, The Majestic}}
\hadithdefcmd{bukhari}{1409}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي قَيْسٌ، عَنِ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ حَسَدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ مَالاً فَسَلَّطَهُ عَلَى هَلَكَتِهِ فِي الْحَقِّ، وَرَجُلٌ آتَاهُ اللَّهُ حِكْمَةً فَهْوَ يَقْضِي بِهَا وَيُعَلِّمُهَا ‏"‏‏.‏\hadithno{1409}\hadithtrans{Narrated Ibn Mas`ud:I heard the Prophet (ﷺ) saying, "There is no envy except in two: a person whom Allah has given wealth and he spends it in the right way, and a person whom Allah has given wisdom (i.e. religious knowledge) and he gives his decisions accordingly and teaches it to the others}}
\hadithdefcmd{bukhari}{1410}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ أَبَا النَّضْرِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ ـ هُوَ ابْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ ـ عَنْ أَبِيهِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَصَدَّقَ بِعَدْلِ تَمْرَةٍ مِنْ كَسْبٍ طَيِّبٍ ـ وَلاَ يَقْبَلُ اللَّهُ إِلاَّ الطَّيِّبَ ـ وَإِنَّ اللَّهَ يَتَقَبَّلُهَا بِيَمِينِهِ، ثُمَّ يُرَبِّيهَا لِصَاحِبِهِ كَمَا يُرَبِّي أَحَدُكُمْ فَلُوَّهُ حَتَّى تَكُونَ مِثْلَ الْجَبَلِ ‏"‏‏.‏ تَابَعَهُ سُلَيْمَانُ عَنِ ابْنِ دِينَارٍ‏.‏ وَقَالَ وَرْقَاءُ عَنِ ابْنِ دِينَارٍ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَرَوَاهُ مُسْلِمُ بْنُ أَبِي مَرْيَمَ وَزَيْدُ بْنُ أَسْلَمَ وَسُهَيْلٌ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1410}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If one gives in charity what equals one date-fruit from the honestly earned money and Allah accepts only the honestly earned money --Allah takes it in His right (hand) and then enlarges its reward for that person (who has given it), as anyone of you brings up his baby horse, so much so that it becomes as big as a mountain}}
\hadithdefcmd{bukhari}{1411}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مَعْبَدُ بْنُ خَالِدٍ، قَالَ سَمِعْتُ حَارِثَةَ بْنَ وَهْبٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَصَدَّقُوا فَإِنَّهُ يَأْتِي عَلَيْكُمْ زَمَانٌ يَمْشِي الرَّجُلُ بِصَدَقَتِهِ، فَلاَ يَجِدُ مَنْ يَقْبَلُهَا يَقُولُ الرَّجُلُ لَوْ جِئْتَ بِهَا بِالأَمْسِ لَقَبِلْتُهَا، فَأَمَّا الْيَوْمَ فَلاَ حَاجَةَ لِي بِهَا ‏"‏‏.‏\hadithno{1411}\hadithtrans{Narrated Haritha bin Wahab:I heard the Prophet (ﷺ) saying, "O people! Give in charity as a time will come upon you when a person will wander about with his object of charity and will not find anybody to accept it, and one (who will be requested to take it) will say, "If you had brought it yesterday, would have taken it, but today I am not in need of it}}
\hadithdefcmd{bukhari}{1412}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَكْثُرَ فِيكُمُ الْمَالُ فَيَفِيضَ، حَتَّى يُهِمَّ رَبَّ الْمَالِ مَنْ يَقْبَلُ صَدَقَتَهُ، وَحَتَّى يَعْرِضَهُ فَيَقُولَ الَّذِي يَعْرِضُهُ عَلَيْهِ لاَ أَرَبَ لِي ‏"‏‏.‏\hadithno{1412}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Hour (Day of Judgment) will not be established till your wealth increases so much so that one will be worried, for no one will accept his Zakat and the person to whom he will give it will reply, 'I am not in need of it}}
\hadithdefcmd{bukhari}{1413}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَاصِمٍ النَّبِيلُ، أَخْبَرَنَا سَعْدَانُ بْنُ بِشْرٍ، حَدَّثَنَا أَبُو مُجَاهِدٍ، حَدَّثَنَا مُحِلُّ بْنُ خَلِيفَةَ الطَّائِيُّ، قَالَ سَمِعْتُ عَدِيَّ بْنَ حَاتِمٍ ـ رضى الله عنه ـ يَقُولُ كُنْتُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَهُ رَجُلاَنِ أَحَدُهُمَا يَشْكُو الْعَيْلَةَ، وَالآخَرُ يَشْكُو قَطْعَ السَّبِيلِ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمَّا قَطْعُ السَّبِيلِ فَإِنَّهُ لاَ يَأْتِي عَلَيْكَ إِلاَّ قَلِيلٌ حَتَّى تَخْرُجَ الْعِيرُ إِلَى مَكَّةَ بِغَيْرِ خَفِيرٍ، وَأَمَّا الْعَيْلَةُ فَإِنَّ السَّاعَةَ لاَ تَقُومُ حَتَّى يَطُوفَ أَحَدُكُمْ بِصَدَقَتِهِ لاَ يَجِدُ مَنْ يَقْبَلُهَا مِنْهُ، ثُمَّ لَيَقِفَنَّ أَحَدُكُمْ بَيْنَ يَدَىِ اللَّهِ لَيْسَ بَيْنَهُ وَبَيْنَهُ حِجَابٌ وَلاَ تُرْجُمَانٌ يُتَرْجِمُ لَهُ، ثُمَّ لَيَقُولَنَّ لَهُ أَلَمْ أُوتِكَ مَالاً فَلَيَقُولَنَّ بَلَى‏.‏ ثُمَّ لَيَقُولَنَّ أَلَمْ أُرْسِلْ إِلَيْكَ رَسُولاً فَلَيَقُولَنَّ بَلَى‏.‏ فَيَنْظُرُ عَنْ يَمِينِهِ فَلاَ يَرَى إِلاَّ النَّارَ، ثُمَّ يَنْظُرُ عَنْ شِمَالِهِ فَلاَ يَرَى إِلاَّ النَّارَ، فَلْيَتَّقِيَنَّ أَحَدُكُمُ النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ، فَإِنْ لَمْ يَجِدْ فَبِكَلِمَةٍ طَيِّبَةٍ ‏"‏‏.‏\hadithno{1413}\hadithtrans{Narrated `Adi bin Hatim:While I was sitting with Allah's Messenger (ﷺ) two persons came to him; one of them complained about his poverty and the other complained about the prevalence of robberies. Allah's Messenger (ﷺ) said, "As regards stealing and robberies, there will shortly come a time when a caravan will go to Mecca (from Medina) without any guard. And regarding poverty, The Hour (Day of Judgment) will not be established till one of you wanders about with his object of charity and will not find anybody to accept it And (no doubt) each one of you will stand in front of Allah and there will be neither a curtain nor an interpreter between him and Allah, and Allah will ask him, 'Did not I give you wealth?' He will reply in the affirmative. Allah will further ask, 'Didn't I send a messenger to you?' And again that person will reply in the affirmative Then he will look to his right and he will see nothing but Hell-fire, and then he will look to his left and will see nothing but Hell-fire. And so, any (each one) of you should save himself from the fire even by giving half of a date-fruit (in charity). And if you do not find a half date-fruit, then (you can do it through saying) a good pleasant word (to your brethren). (See Hadith No. 793 Vol)}}
\hadithdefcmd{bukhari}{1414}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيَأْتِيَنَّ عَلَى النَّاسِ زَمَانٌ يَطُوفُ الرَّجُلُ فِيهِ بِالصَّدَقَةِ مِنَ الذَّهَبِ ثُمَّ لاَ يَجِدُ أَحَدًا يَأْخُذُهَا مِنْهُ، وَيُرَى الرَّجُلُ الْوَاحِدُ يَتْبَعُهُ أَرْبَعُونَ امْرَأَةً، يَلُذْنَ بِهِ مِنْ قِلَّةِ الرِّجَالِ وَكَثْرَةِ النِّسَاءِ ‏"‏‏.‏\hadithno{1414}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "A time will come upon the people when a person will wander about with gold as Zakat and will not find anybody to accept it, and one man will be seen followed by forty women to be their guardian because of scarcity of men and great number of women}}
\hadithdefcmd{bukhari}{1415}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو النُّعْمَانِ الْحَكَمُ ـ هُوَ ابْنُ عَبْدِ اللَّهِ الْبَصْرِيُّ ـ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مَسْعُودٍ ـ رضى الله عنه ـ قَالَ لَمَّا نَزَلَتْ آيَةُ الصَّدَقَةِ كُنَّا نُحَامِلُ، فَجَاءَ رَجُلٌ فَتَصَدَّقَ بِشَىْءٍ كَثِيرٍ فَقَالُوا مُرَائِي‏.‏ وَجَاءَ رَجُلٌ فَتَصَدَّقَ بِصَاعٍ فَقَالُوا إِنَّ اللَّهَ لَغَنِيٌّ عَنْ صَاعِ هَذَا‏.‏ فَنَزَلَتِ ‏\{‏الَّذِينَ يَلْمِزُونَ الْمُطَّوِّعِينَ مِنَ الْمُؤْمِنِينَ فِي الصَّدَقَاتِ وَالَّذِينَ لاَ يَجِدُونَ إِلاَّ جُهْدَهُمْ‏\}‏ الآيَةَ‏.‏\hadithno{1415}\hadithtrans{Narrated Abu Mas`ud:When the verses of charity were revealed, we used to work as porters. A man came and distributed objects of charity in abundance. And they (the people) said, "He is showing off." And another man came and gave a Sa (a small measure of food grains); they said, "Allah is not in need of this small amount of charity." And then the Divine Inspiration came: "Those who criticize such of the believers who give in charity voluntarily and those who could not find to give in charity except what is available to them}}
\hadithdefcmd{bukhari}{1416}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ ـ رضى الله عنه ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَمَرَنَا بِالصَّدَقَةِ انْطَلَقَ أَحَدُنَا إِلَى السُّوقِ فَتَحَامَلَ فَيُصِيبُ الْمُدَّ، وَإِنَّ لِبَعْضِهِمُ الْيَوْمَ لَمِائَةَ أَلْفٍ‏.‏\hadithno{1416}\hadithtrans{Narrated Abu Mas`ud Al-Ansari:Whenever Allah's Messenger (ﷺ) ordered us to give in charity, we used to go to the market and work as porters and get a Mudd (a special measure of grain) and then give it in charity. (Those were the days of poverty) and today some of us have one hundred thousand}}
\hadithdefcmd{bukhari}{1417}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَعْقِلٍ، قَالَ سَمِعْتُ عَدِيَّ بْنَ حَاتِمٍ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اتَّقُوا النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ ‏"‏‏.‏\hadithno{1417}\hadithtrans{Narrated `Adi bin Hatim heard the Prophet (ﷺ) saying:"Save yourself from Hell-fire even by giving half a date-fruit in charity}}
\hadithdefcmd{bukhari}{1418}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَخَلَتِ امْرَأَةٌ مَعَهَا ابْنَتَانِ لَهَا تَسْأَلُ، فَلَمْ تَجِدْ عِنْدِي شَيْئًا غَيْرَ تَمْرَةٍ فَأَعْطَيْتُهَا إِيَّاهَا، فَقَسَمَتْهَا بَيْنَ ابْنَتَيْهَا وَلَمْ تَأْكُلْ مِنْهَا، ثُمَّ قَامَتْ فَخَرَجَتْ، فَدَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَيْنَا، فَأَخْبَرْتُهُ فَقَالَ ‏ "‏ مَنِ ابْتُلِيَ مِنْ هَذِهِ الْبَنَاتِ بِشَىْءٍ كُنَّ لَهُ سِتْرًا مِنَ النَّارِ ‏"‏‏.‏\hadithno{1418}\hadithtrans{Narrated Aisha:A lady along with her two daughters came to me asking (for some alms), but she found nothing with me except one date which I gave to her and she divided it between her two daughters, and did not eat anything herself, and then she got up and went away. Then the Prophet (ﷺ) came in and I informed him about this story. He said, "Whoever is put to trial by these daughters and he treats them generously (with benevolence) then these daughters will act as a shield for him from Hell-Fire." (See Hadith No. 24, Vol)}}
\hadithdefcmd{bukhari}{1419}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا عُمَارَةُ بْنُ الْقَعْقَاعِ، حَدَّثَنَا أَبُو زُرْعَةَ، حَدَّثَنَا أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ الصَّدَقَةِ أَعْظَمُ أَجْرًا قَالَ ‏ "‏ أَنْ تَصَدَّقَ وَأَنْتَ صَحِيحٌ شَحِيحٌ، تَخْشَى الْفَقْرَ وَتَأْمُلُ الْغِنَى، وَلاَ تُمْهِلُ حَتَّى إِذَا بَلَغَتِ الْحُلْقُومَ قُلْتَ لِفُلاَنٍ كَذَا، وَلِفُلاَنٍ كَذَا، وَقَدْ كَانَ لِفُلاَنٍ ‏"‏‏.‏\hadithno{1419}\hadithtrans{Narrated Abu Huraira:A man came to the Prophet (ﷺ) and asked, "O Allah's Messenger (ﷺ)! Which charity is the most superior in reward?" He replied, "The charity which you practice while you are healthy, niggardly and afraid of poverty and wish to become wealthy. Do not delay it to the time of approaching death and then say, 'Give so much to such and such, and so much to such and such.' And it has already belonged to such and such (as it is too late)}}
\hadithdefcmd{bukhari}{1420}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ فِرَاسٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ بَعْضَ، أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم قُلْنَ لِلنَّبِيِّ صلى الله عليه وسلم أَيُّنَا أَسْرَعُ بِكَ لُحُوقًا قَالَ ‏ "‏ أَطْوَلُكُنَّ يَدًا ‏"‏‏.‏ فَأَخَذُوا قَصَبَةً يَذْرَعُونَهَا، فَكَانَتْ سَوْدَةُ أَطْوَلَهُنَّ يَدًا، فَعَلِمْنَا بَعْدُ أَنَّمَا كَانَتْ طُولَ يَدِهَا الصَّدَقَةُ، وَكَانَتْ أَسْرَعَنَا لُحُوقًا بِهِ وَكَانَتْ تُحِبُّ الصَّدَقَةَ‏.‏\hadithno{1420}\hadithtrans{Narrated `Aisha:Some of the wives of the Prophet (ﷺ) asked him, "Who amongst us will be the first to follow you (i.e. die after you)?" He said, "Whoever has the longest hand." So they started measuring their hands with a stick and Sauda's hand turned out to be the longest. (When Zainab bint Jahsh died first of all in the caliphate of `Umar), we came to know that the long hand was a symbol of practicing charity, so she was the first to follow the Prophet (ﷺ) and she used to love to practice charity. (Sauda died later in the caliphate of Muawiya)}}
\hadithdefcmd{bukhari}{1421}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ رَجُلٌ لأَتَصَدَّقَنَّ بِصَدَقَةٍ‏.‏ فَخَرَجَ بِصَدَقَتِهِ فَوَضَعَهَا فِي يَدِ سَارِقٍ فَأَصْبَحُوا يَتَحَدَّثُونَ تُصُدِّقَ عَلَى سَارِقٍ‏.‏ فَقَالَ اللَّهُمَّ لَكَ الْحَمْدُ لأَتَصَدَّقَنَّ بِصَدَقَةٍ‏.‏ فَخَرَجَ بِصَدَقَتِهِ فَوَضَعَهَا فِي يَدَىْ زَانِيَةٍ، فَأَصْبَحُوا يَتَحَدَّثُونَ تُصُدِّقَ اللَّيْلَةَ عَلَى زَانِيَةٍ‏.‏ فَقَالَ اللَّهُمَّ لَكَ الْحَمْدُ عَلَى زَانِيَةٍ، لأَتَصَدَّقَنَّ بِصَدَقَةٍ‏.‏ فَخَرَجَ بِصَدَقَتِهِ فَوَضَعَهَا فِي يَدَىْ غَنِيٍّ فَأَصْبَحُوا يَتَحَدَّثُونَ تُصُدِّقَ عَلَى غَنِيٍّ فَقَالَ اللَّهُمَّ لَكَ الْحَمْدُ، عَلَى سَارِقٍ وَعَلَى زَانِيَةٍ وَعَلَى غَنِيٍّ‏.‏ فَأُتِيَ فَقِيلَ لَهُ أَمَّا صَدَقَتُكَ عَلَى سَارِقٍ فَلَعَلَّهُ أَنْ يَسْتَعِفَّ عَنْ سَرِقَتِهِ، وَأَمَّا الزَّانِيَةُ فَلَعَلَّهَا أَنْ تَسْتَعِفَّ عَنْ زِنَاهَا، وَأَمَّا الْغَنِيُّ فَلَعَلَّهُ يَعْتَبِرُ فَيُنْفِقُ مِمَّا أَعْطَاهُ اللَّهُ ‏"‏‏.‏\hadithno{1421}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "A man said that he would give something in charity. He went out with his object of charity and unknowingly gave it to a thief. Next morning the people said that he had given his object of charity to a thief. (On hearing that) he said, "O Allah! All the praises are for you. I will give alms again." And so he again went out with his alms and (unknowingly) gave it to an adulteress. Next morning the people said that he had given his alms to an adulteress last night. The man said, "O Allah! All the praises are for you. (I gave my alms) to an adulteress. I will give alms again." So he went out with his alms again and (unknowingly) gave it to a rich person. (The people) next morning said that he had given his alms to a wealthy person. He said, "O Allah! All the praises are for you. (I had given alms) to a thief, to an adulteress and to a wealthy man." Then someone came and said to him, "The alms which you gave to the thief, might make him abstain from stealing, and that given to the adulteress might make her abstain from illegal sexual intercourse (adultery), and that given to the wealthy man might make him take a lesson from it and spend his wealth which Allah has given him, in Allah's cause}}
\hadithdefcmd{bukhari}{1422}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا إِسْرَائِيلُ، حَدَّثَنَا أَبُو الْجُوَيْرِيَةِ، أَنَّ مَعْنَ بْنَ يَزِيدَ ـ رضى الله عنه ـ حَدَّثَهُ قَالَ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَا وَأَبِي وَجَدِّي وَخَطَبَ عَلَىَّ فَأَنْكَحَنِي وَخَاصَمْتُ إِلَيْهِ ـ وَـ كَانَ أَبِي يَزِيدُ أَخْرَجَ دَنَانِيرَ يَتَصَدَّقُ بِهَا فَوَضَعَهَا عِنْدَ رَجُلٍ فِي الْمَسْجِدِ، فَجِئْتُ فَأَخَذْتُهَا فَأَتَيْتُهُ بِهَا فَقَالَ وَاللَّهِ مَا إِيَّاكَ أَرَدْتُ‏.‏ فَخَاصَمْتُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَكَ مَا نَوَيْتَ يَا يَزِيدُ، وَلَكَ مَا أَخَذْتَ يَا مَعْنُ ‏"‏‏.‏\hadithno{1422}\hadithtrans{Narrated Ma'n bin Yazid:My grandfather, my father and I gave the pledge of allegiance to Allah's Messenger (ﷺ). The Prophet (ﷺ) got me engaged and then got me married. One day I went to the Prophet (ﷺ) with a complaint. My father Yazid had taken some gold coins for charity and kept them with a man in the mosque (to give them to the poor) But I went and took them and brought them to him (my father). My father said, "By Allah! I did not intend to give them to you. " I took (the case) to Allah's Messenger (ﷺ) . On that Allah's Messenger (ﷺ) said, "O Yazid, you will be rewarded for what you intended. O Ma'n, whatever you have taken is yours}}
\hadithdefcmd{bukhari}{1423}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي خُبَيْبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ سَبْعَةٌ يُظِلُّهُمُ اللَّهُ تَعَالَى فِي ظِلِّهِ يَوْمَ لاَ ظِلَّ إِلاَّ ظِلُّهُ إِمَامٌ عَدْلٌ، وَشَابٌّ نَشَأَ فِي عِبَادَةِ اللَّهِ، وَرَجُلٌ قَلْبُهُ مُعَلَّقٌ فِي الْمَسَاجِدِ، وَرَجُلاَنِ تَحَابَّا فِي اللَّهِ اجْتَمَعَا عَلَيْهِ وَتَفَرَّقَا عَلَيْهِ، وَرَجُلٌ دَعَتْهُ امْرَأَةٌ ذَاتُ مَنْصِبٍ وَجَمَالٍ فَقَالَ إِنِّي أَخَافُ اللَّهَ، وَرَجُلٌ تَصَدَّقَ بِصَدَقَةٍ فَأَخْفَاهَا حَتَّى لاَ تَعْلَمَ شِمَالُهُ مَا تُنْفِقُ يَمِينُهُ، وَرَجُلٌ ذَكَرَ اللَّهَ خَالِيًا فَفَاضَتْ عَيْنَاهُ ‏"‏‏.‏\hadithno{1423}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Seven people will be shaded by Allah under His shade on the day when there will be no shade except His. They are: (1) a just ruler; (2) a young man who has been brought up in the worship of Allah, (i.e. worship Allah (Alone) sincerely from his childhood), (3) a man whose heart is attached to the mosque (who offers the five compulsory congregational prayers in the mosque); (4) two persons who love each other only for Allah's sake and they meet and part in Allah's cause only; (5) a man who refuses the call of a charming woman of noble birth for an illegal sexual intercourse with her and says: I am afraid of Allah; (6) a person who practices charity so secretly that his left hand does not know what his right hand has given (i.e. nobody knows how much he has given in charity). (7) a person who remembers Allah in seclusion and his eyes get flooded with tears}}
\hadithdefcmd{bukhari}{1424}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، أَخْبَرَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي مَعْبَدُ بْنُ خَالِدٍ، قَالَ سَمِعْتُ حَارِثَةَ بْنَ وَهْبٍ الْخُزَاعِيَّ ـ رضى الله عنه ـ يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَصَدَّقُوا، فَسَيَأْتِي عَلَيْكُمْ زَمَانٌ يَمْشِي الرَّجُلُ بِصَدَقَتِهِ فَيَقُولُ الرَّجُلُ لَوْ جِئْتَ بِهَا بِالأَمْسِ لَقَبِلْتُهَا مِنْكَ، فَأَمَّا الْيَوْمَ فَلاَ حَاجَةَ لِي فِيهَا ‏"‏‏.‏\hadithno{1424}\hadithtrans{Narrated Haritha bin Wahab Al-Khuza`i:I heard the Prophet (ﷺ) saying, "(O people!) Give in charity (for Allah's cause) because a time will come when a person will carry his object of charity from place to place (and he will not find any person to take it) and any person whom he shall request to take it, will reply, 'If you had brought it yesterday I would have taken it, but today I am not in need of it}}
\hadithdefcmd{bukhari}{1425}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَنْفَقَتِ الْمَرْأَةُ مِنْ طَعَامِ بَيْتِهَا غَيْرَ مُفْسِدَةٍ كَانَ لَهَا أَجْرُهَا بِمَا أَنْفَقَتْ وَلِزَوْجِهَا أَجْرُهُ بِمَا كَسَبَ، وَلِلْخَازِنِ مِثْلُ ذَلِكَ، لاَ يَنْقُصُ بَعْضُهُمْ أَجْرَ بَعْضٍ شَيْئًا ‏"‏‏.‏\hadithno{1425}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "When a woman gives in charity some of the foodstuff (which she has in her house) without spoiling it, she will receive the reward for what she has spent, and her husband will receive the reward because of his earning, and the storekeeper will also have a reward similar to it. The reward of one will not decrease the reward of the others}}
\hadithdefcmd{bukhari}{1426}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ الصَّدَقَةِ مَا كَانَ عَنْ ظَهْرِ غِنًى، وَابْدَأْ بِمَنْ تَعُولُ ‏"‏‏.‏\hadithno{1426}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The best charity is that which is practiced by a wealthy person. And start giving first to your dependents}}
\hadithdefcmd{bukhari}{1428}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ حَكِيمِ بْنِ حِزَامٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى، وَابْدَأْ بِمَنْ تَعُولُ، وَخَيْرُ الصَّدَقَةِ عَنْ ظَهْرِ غِنًى، وَمَنْ يَسْتَعْفِفْ يُعِفَّهُ اللَّهُ، وَمَنْ يَسْتَغْنِ يُغْنِهِ اللَّهُ ‏"‏‏.‏ وَعَنْ وُهَيْبٍ، قَالَ أَخْبَرَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ بِهَذَا‏.‏\hadithno{1428}\hadithtrans{Narrated Hakim bin Hizam:The Prophet (ﷺ) said, "The upper hand is better than the lower hand (i.e. he who gives in charity is better than him who takes it). One should start giving first to his dependents. And the best object of charity is that which is given by a wealthy person (from the money which is left after his expenses). And whoever abstains from asking others for some financial help, Allah will give him and save him from asking others, Allah will make him self-sufficient}}
\hadithdefcmd{bukhari}{1429}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم ح‏.‏ وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَهُوَ عَلَى الْمِنْبَرِ، وَذَكَرَ الصَّدَقَةَ وَالتَّعَفُّفَ وَالْمَسْأَلَةَ ‏ "‏ الْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى، فَالْيَدُ الْعُلْيَا هِيَ الْمُنْفِقَةُ، وَالسُّفْلَى هِيَ السَّائِلَةُ ‏"‏‏.‏\hadithno{1429}\hadithtrans{Narrated Ibn `Umar:I heard Allah's Messenger (ﷺ) while he was on the pulpit speaking about charity, to abstain from asking others for some financial help and about begging others, saying, "The upper hand is better than the lower hand. The upper hand is that of the giver and the lower (hand) is that of the beggar}}
\hadithdefcmd{bukhari}{1430}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عُمَرَ بْنِ سَعِيدٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، أَنَّ عُقْبَةَ بْنَ الْحَارِثِ ـ رضى الله عنه ـ حَدَّثَهُ قَالَ صَلَّى بِنَا النَّبِيُّ صلى الله عليه وسلم الْعَصْرَ، فَأَسْرَعَ ثُمَّ دَخَلَ الْبَيْتَ، فَلَمْ يَلْبَثْ أَنْ خَرَجَ، فَقُلْتُ أَوْ قِيلَ لَهُ فَقَالَ ‏ "‏ كُنْتُ خَلَّفْتُ فِي الْبَيْتِ تِبْرًا مِنَ الصَّدَقَةِ، فَكَرِهْتُ أَنْ أُبَيِّتَهُ فَقَسَمْتُهُ ‏"‏‏.‏\hadithno{1430}\hadithtrans{Narrated `Uqba bin Al-Harith:Once the Prophet (ﷺ) offered the `Asr prayer and then hurriedly went to his house and returned immediately. I (or somebody else) asked him (as to what was the matter) and he said, "I left at home a piece of gold which was from the charity and I disliked to let it remain a night in my house, so I got it distributed}}
\hadithdefcmd{bukhari}{1431}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَدِيٌّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ عِيدٍ فَصَلَّى رَكْعَتَيْنِ لَمْ يُصَلِّ قَبْلُ وَلاَ بَعْدُ، ثُمَّ مَالَ عَلَى النِّسَاءِ وَمَعَهُ بِلاَلٌ، فَوَعَظَهُنَّ وَأَمَرَهُنَّ أَنْ يَتَصَدَّقْنَ، فَجَعَلَتِ الْمَرْأَةُ تُلْقِي الْقُلْبَ وَالْخُرْصَ‏.‏\hadithno{1431}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) went out for the `Id prayer on the `Id day and offered a two rak`at prayer; and he neither offered a prayer before it or after it. Then he went towards the women along with Bilal. He preached them and ordered them to give in charity. And some (amongst the women) started giving their forearm bangles and earrings}}
\hadithdefcmd{bukhari}{1432}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا أَبُو بُرْدَةَ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، حَدَّثَنَا أَبُو بُرْدَةَ بْنُ أَبِي مُوسَى، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا جَاءَهُ السَّائِلُ، أَوْ طُلِبَتْ إِلَيْهِ حَاجَةٌ قَالَ ‏ "‏ اشْفَعُوا تُؤْجَرُوا، وَيَقْضِي اللَّهُ عَلَى لِسَانِ نَبِيِّهِ صلى الله عليه وسلم مَا شَاءَ ‏"‏‏.‏\hadithno{1432}\hadithtrans{Narrated Abu Burda bin Abu Musa:that his father said, "Whenever a beggar came to Allah's Messenger (ﷺ) or he was asked for something, he used to say (to his companions), "Help and recommend him and you will receive the reward for it; and Allah will bring about what He will through His Prophet's tongue}}
\hadithdefcmd{bukhari}{1433}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ ـ رضى الله عنها ـ قَالَتْ قَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تُوكِي فَيُوكَى عَلَيْكِ ‏"‏‏.‏ حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، عَنْ عَبْدَةَ، وَقَالَ، ‏"‏ لاَ تُحْصِي فَيُحْصِيَ اللَّهُ عَلَيْكِ ‏"‏\hadithno{1433}\hadithtrans{Narrated Asma:The Prophet (ﷺ) said to me, "Do not withhold your money, (for if you did so) Allah would withhold His blessings from you." Narrated `Abda: The Prophet (ﷺ) said, "Do not withhold your money by counting it (i.e. hoarding it), (for if you did so), Allah would also withhold His blessings from you}}
\hadithdefcmd{bukhari}{1434}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، عَنْ حَجَّاجِ بْنِ مُحَمَّدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَخْبَرَهُ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ أَنَّهَا جَاءَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تُوعِي فَيُوعِيَ اللَّهُ عَلَيْكِ، ارْضَخِي مَا اسْتَطَعْتِ ‏"‏‏.‏\hadithno{1434}\hadithtrans{Narrated Asma' bint Abu Bakr:that she had gone to the Prophet (ﷺ) and he said, "Do not shut your money bag; otherwise Allah too will withhold His blessings from you. Spend (in Allah's Cause) as much as you can afford}}
\hadithdefcmd{bukhari}{1435}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ ـ رضى الله عنه ـ قَالَ قَالَ عُمَرُ ـ رضى الله عنه ـ أَيُّكُمْ يَحْفَظُ حَدِيثَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَنِ الْفِتْنَةِ قَالَ قُلْتُ أَنَا أَحْفَظُهُ كَمَا قَالَ‏.‏ قَالَ إِنَّكَ عَلَيْهِ لَجَرِيءٌ فَكَيْفَ قَالَ قُلْتُ فِتْنَةُ الرَّجُلِ فِي أَهْلِهِ وَوَلَدِهِ وَجَارِهِ تُكَفِّرُهَا الصَّلاَةُ وَالصَّدَقَةُ وَالْمَعْرُوفُ‏.‏ قَالَ سُلَيْمَانُ قَدْ كَانَ يَقُولُ ‏ "‏ الصَّلاَةُ وَالصَّدَقَةُ، وَالأَمْرُ بِالْمَعْرُوفِ وَالنَّهْىُ عَنِ الْمُنْكَرِ ‏"‏‏.‏ قَالَ لَيْسَ هَذِهِ أُرِيدُ، وَلَكِنِّي أُرِيدُ الَّتِي تَمُوجُ كَمَوْجِ الْبَحْرِ‏.‏ قَالَ قُلْتُ لَيْسَ عَلَيْكَ بِهَا يَا أَمِيرَ الْمُؤْمِنِينَ بَأْسٌ، بَيْنَكَ وَبَيْنَهَا باب مُغْلَقٌ‏.‏ قَالَ فَيُكْسَرُ الْبَابُ أَوْ يُفْتَحُ‏.‏ قَالَ قُلْتُ لاَ‏.‏ بَلْ يُكْسَرُ‏.‏ قَالَ فَإِنَّهُ إِذَا كُسِرَ لَمْ يُغْلَقْ أَبَدًا‏.‏ قَالَ قُلْتُ أَجَلْ‏.‏ فَهِبْنَا أَنْ نَسْأَلَهُ مَنِ الْبَابُ فَقُلْنَا لِمَسْرُوقٍ سَلْهُ‏.‏ قَالَ فَسَأَلَهُ‏.‏ فَقَالَ عُمَرُ ـ رضى الله عنه ـ‏.‏ قَالَ قُلْنَا فَعَلِمَ عُمَرُ مَنْ تَعْنِي قَالَ نَعَمْ، كَمَا أَنَّ دُونَ غَدٍ لَيْلَةً، وَذَلِكَ أَنِّي حَدَّثْتُهُ حَدِيثًا لَيْسَ بِالأَغَالِيطِ‏.‏\hadithno{1435}\hadithtrans{Narrated Abu Wail:Hudhaifa said, "`Umar said, 'Who amongst you remembers the statement of Allah's Messenger (ﷺ) about afflictions'?' I said, 'I know it as the Prophet (ﷺ) had said it.' `Umar said, 'No doubt, you are bold. How did he say it?' I said, 'A man's afflictions (wrong deeds) concerning his wife, children and neighbors are expiated by (his) prayers, charity, and enjoining good.' (The sub-narrator Sulaiman added that he said, 'The prayer, charity, enjoining good and forbidding evil.') `Umar said, 'I did not mean that, but I ask about that affliction which will spread like the waves of the sea.' I said, 'O chief of the believers! You need not be afraid of it as there is a closed door between you and it.' He asked, 'Will the door be broken or opened?' I replied, 'No, it will be broken.' He said, 'Then, if it is broken, it will never be closed again?' I replied, 'Yes.' " Then we were afraid to ask what that door was, so we asked Masruq to inquire, and he asked Hudhaifa regarding it. Hudhaifa said, "The door was `Umar. "We further asked Hudhaifa whether `Umar knew what that door meant. Hudhaifa replied in the affirmative and added, "He knew it as one knows that there will be a night before the tomorrow morning}}
\hadithdefcmd{bukhari}{1436}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ حَكِيمِ بْنِ حِزَامٍ ـ رضى الله عنه ـ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ أَشْيَاءَ كُنْتُ أَتَحَنَّثُ بِهَا فِي الْجَاهِلِيَّةِ مِنْ صَدَقَةٍ أَوْ عَتَاقَةٍ وَصِلَةِ رَحِمٍ فَهَلْ فِيهَا مِنْ أَجْرٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَسْلَمْتَ عَلَى مَا سَلَفَ مِنْ خَيْرٍ ‏"‏‏.‏\hadithno{1436}\hadithtrans{Narrated Hakim bin Hizam:I said to Allah's Messenger (ﷺ), "Before embracing Islam I used to do good deeds like giving in charity, slave-manumitting, and the keeping of good relations with Kith and kin. Shall I be rewarded for those deeds?" The Prophet (ﷺ) replied, "You became Muslim with all those good deeds (Without losing their reward)}}
\hadithdefcmd{bukhari}{1437}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَصَدَّقَتِ الْمَرْأَةُ مِنْ طَعَامِ زَوْجِهَا غَيْرَ مُفْسِدَةٍ كَانَ لَهَا أَجْرُهَا، وَلِزَوْجِهَا بِمَا كَسَبَ، وَلِلْخَازِنِ مِثْلُ ذَلِكَ ‏"‏‏.‏\hadithno{1437}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "When a woman gives in charity from her husband's meals without wasting the property of her husband, she will get a reward for it, and her husband too will get a reward for what he earned and the storekeeper will have the reward likewise}}
\hadithdefcmd{bukhari}{1438}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَازِنُ الْمُسْلِمُ الأَمِينُ الَّذِي يُنْفِذُ ـ وَرُبَّمَا قَالَ يُعْطِي ـ مَا أُمِرَ بِهِ كَامِلاً مُوَفَّرًا طَيِّبٌ بِهِ نَفْسُهُ، فَيَدْفَعُهُ إِلَى الَّذِي أُمِرَ لَهُ بِهِ، أَحَدُ الْمُتَصَدِّقَيْنِ ‏"‏‏.‏\hadithno{1438}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "An honest Muslim storekeeper who carries out the orders of his master and pays fully what he has been ordered to give with a good heart and pays to that person to whom he was ordered to pay, is regarded as one of the two charitable persons}}
\hadithdefcmd{bukhari}{1439}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مَنْصُورٌ، وَالأَعْمَشُ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ عَنِ النَّبِيِّ صلى الله عليه وسلم تَعْنِي إِذَا تَصَدَّقَتِ الْمَرْأَةُ مِنْ بَيْتِ زَوْجِهَا‏.‏\hadithno{1439}\hadithtrans{Narrated 'Aishah:The Prophet (ﷺ) said, "If a woman gives in charity from her husband's house ..." (See next hadith)}}
\hadithdefcmd{bukhari}{1440}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا أَطْعَمَتِ الْمَرْأَةُ مِنْ بَيْتِ زَوْجِهَا غَيْرَ مُفْسِدَةٍ، لَهَا أَجْرُهَا، وَلَهُ مِثْلُهُ، وَلِلْخَازِنِ مِثْلُ ذَلِكَ، لَهُ بِمَا اكْتَسَبَ، وَلَهَا بِمَا أَنْفَقَتْ ‏"‏‏.‏\hadithno{1440}\hadithtrans{Narrate Aisha:The Prophet (ﷺ) said, "If a woman gives in charity from her husband's house .." The Prophet (ﷺ) also said, "If a lady gives meals (in charity) from her husband's house without spoiling her husband's property, she will get a reward and her husband will also get a reward likewise. The husband will get a reward because of his earnings and the woman because of her spending}}
\hadithdefcmd{bukhari}{1441}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَنْفَقَتِ الْمَرْأَةُ مِنْ طَعَامِ بَيْتِهَا غَيْرَ مُفْسِدَةٍ فَلَهَا أَجْرُهَا، وَلِلزَّوْجِ بِمَا اكْتَسَبَ، وَلِلْخَازِنِ مِثْلُ ذَلِكَ ‏"‏‏.‏\hadithno{1441}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "When a woman gives in charity from her house meals in Allah's Cause without spoiling her husband's property, she will get a reward for it, and her husband will also get the reward for his earnings and the storekeeper will get a reward likewise}}
\hadithdefcmd{bukhari}{1442}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ مُعَاوِيَةَ بْنِ أَبِي مُزَرِّدٍ، عَنْ أَبِي الْحُبَابِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ يَوْمٍ يُصْبِحُ الْعِبَادُ فِيهِ إِلاَّ مَلَكَانِ يَنْزِلاَنِ فَيَقُولُ أَحَدُهُمَا اللَّهُمَّ أَعْطِ مُنْفِقًا خَلَفًا، وَيَقُولُ الآخَرُ اللَّهُمَّ أَعْطِ مُمْسِكًا تَلَفًا ‏"‏‏.‏\hadithno{1442}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Every day two angels come down from Heaven and one of them says, 'O Allah! Compensate every person who spends in Your Cause,' and the other (angel) says, 'O Allah! Destroy every miser}}
\hadithdefcmd{bukhari}{1443}{حَدَّثَنَا مُوسَى، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَثَلُ الْبَخِيلِ وَالْمُتَصَدِّقِ كَمَثَلِ رَجُلَيْنِ، عَلَيْهِمَا جُبَّتَانِ مِنْ حَدِيدٍ ‏"‏‏.‏ وَحَدَّثَنَا أَبُو الْيَمَانِ أَخْبَرَنَا شُعَيْبٌ حَدَّثَنَا أَبُو الزِّنَادِ أَنَّ عَبْدَ الرَّحْمَنِ حَدَّثَهُ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَثَلُ الْبَخِيلِ وَالْمُنْفِقِ كَمَثَلِ رَجُلَيْنِ، عَلَيْهِمَا جُبَّتَانِ مِنْ حَدِيدٍ، مِنْ ثُدِيِّهِمَا إِلَى تَرَاقِيهِمَا، فَأَمَّا الْمُنْفِقُ فَلاَ يُنْفِقُ إِلاَّ سَبَغَتْ ـ أَوْ وَفَرَتْ ـ عَلَى جِلْدِهِ حَتَّى تُخْفِيَ بَنَانَهُ وَتَعْفُوَ أَثَرَهُ، وَأَمَّا الْبَخِيلُ فَلاَ يُرِيدُ أَنْ يُنْفِقَ شَيْئًا إِلاَّ لَزِقَتْ كُلُّ حَلْقَةٍ مَكَانَهَا، فَهُوَ يُوَسِّعُهَا وَلاَ تَتَّسِعُ ‏"‏‏.‏ تَابَعَهُ الْحَسَنُ بْنُ مُسْلِمٍ عَنْ طَاوُسٍ فِي الْجُبَّتَيْنِ‏.‏\hadithno{1443}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The example of a miser and an almsgiver is like the example of two persons wearing iron cloaks." Allah's Messenger (ﷺ) also said, "The example of an almsgiver and a miser is like the example of two persons who have two iron cloaks on them from their breasts to their collar bones, and when the almsgiver wants to give in charity, the cloak becomes capacious till it covers his whole body to such an extent that it hides his fingertips and covers his footprints (obliterates his tracks). (1) And when the miser wants to spend, it (the iron cloak) sticks and every ring gets stuck to its place and he tries to widen it, but it did not become wide}}
\hadithdefcmd{bukhari}{1444}{وَقَالَ حَنْظَلَةُ عَنْ طَاوُسٍ، ‏"‏ جُنَّتَانِ ‏"‏‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرٌ، عَنِ ابْنِ هُرْمُزٍ، سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ جُنَّتَانِ ‏"‏‏.‏\hadithno{1444}\hadithtrans{See previous hadith}}
\hadithdefcmd{bukhari}{1445}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ عَلَى كُلِّ مُسْلِمٍ صَدَقَةٌ ‏"‏‏.‏ فَقَالُوا يَا نَبِيَّ اللَّهِ فَمَنْ لَمْ يَجِدْ قَالَ ‏"‏ يَعْمَلُ بِيَدِهِ فَيَنْفَعُ نَفْسَهُ وَيَتَصَدَّقُ ‏"‏‏.‏ قَالُوا فَإِنْ لَمْ يَجِدْ قَالَ ‏"‏ يُعِينُ ذَا الْحَاجَةِ الْمَلْهُوفَ ‏"‏‏.‏ قَالُوا فَإِنْ لَمْ يَجِدْ‏.‏ قَالَ ‏"‏ فَلْيَعْمَلْ بِالْمَعْرُوفِ، وَلْيُمْسِكْ عَنِ الشَّرِّ فَإِنَّهَا لَهُ صَدَقَةٌ ‏"‏‏.‏\hadithno{1445}\hadithtrans{Narrated Abu Burda:from his father from his grandfather that the Prophet (ﷺ) said, "Every Muslim has to give in charity." The people asked, "O Allah's Prophet! If someone has nothing to give, what will he do?" He said, "He should work with his hands and benefit himself and also give in charity (from what he earns)." The people further asked, "If he cannot find even that?" He replied, "He should help the needy who appeal for help." Then the people asked, "If he cannot do that?" He replied, "Then he should perform good deeds and keep away from evil deeds and this will be regarded as charitable deeds}}
\hadithdefcmd{bukhari}{1446}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو شِهَابٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ ـ رضى الله عنها ـ قَالَتْ بُعِثَ إِلَى نُسَيْبَةَ الأَنْصَارِيَّةِ بِشَاةٍ فَأَرْسَلَتْ إِلَى عَائِشَةَ ـ رضى الله عنها ـ مِنْهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عِنْدَكُمْ شَىْءٌ ‏"‏‏.‏ فَقُلْتُ لاَ إِلاَّ مَا أَرْسَلَتْ بِهِ نُسَيْبَةُ مِنْ تِلْكَ الشَّاةِ فَقَالَ ‏"‏ هَاتِ فَقَدْ بَلَغَتْ مَحِلَّهَا ‏"‏‏.‏\hadithno{1446}\hadithtrans{Narrated Um 'Atiyya:A sheep was sent to me (Nusaiba Al-Ansariya) (in charity) and I sent some of it to `Aisha. The Prophet asked `Aisha for something to eat. `Aisha replied that there was nothing except what Nusaiba Al-Ansariya had sent of that sheep. The Prophet (ﷺ) said to her, "Bring it as it has reached its place}}
\hadithdefcmd{bukhari}{1447}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ مِنَ الإِبِلِ، وَلَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ، وَلَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ ‏"‏‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، قَالَ أَخْبَرَنِي عَمْرٌو، سَمِعَ أَبَاهُ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم بِهَذَا‏.‏\hadithno{1447}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "There is no Zakat on less than five camels and also there is no Zakat on less than five Awaq (of silver). (5 Awaq = 22 Fransa Riyals of Yemen or 200 Dirhams.) And there is no Zakat on less than five Awsuq. (A special measure of food-grains, and one Wasq equals 60 Sa's.) (For gold 20, Dinars i.e. equal to 12 Guinea English. No Zakat for less than 12 Guinea (English) of gold or for silver less than 22 Fransa Riyals of Yemen.) Narrated Abi Sa`id Al-Khudri: I heard the Prophet (ﷺ) saying (as above)}}
\hadithdefcmd{bukhari}{1448}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي ثُمَامَةُ، أَنَّ أَنَسًا ـ رضى الله عنه ـ حَدَّثَهُ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ كَتَبَ لَهُ الَّتِي أَمَرَ اللَّهُ رَسُولَهُ صلى الله عليه وسلم ‏ "‏ وَمَنْ بَلَغَتْ صَدَقَتُهُ بِنْتَ مَخَاضٍ وَلَيْسَتْ عِنْدَهُ وَعِنْدَهُ بِنْتُ لَبُونٍ فَإِنَّهَا تُقْبَلُ مِنْهُ، وَيُعْطِيهِ الْمُصَدِّقُ عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ، فَإِنْ لَمْ يَكُنْ عِنْدَهُ بِنْتُ مَخَاضٍ عَلَى وَجْهِهَا، وَعِنْدَهُ ابْنُ لَبُونٍ فَإِنَّهُ يُقْبَلُ مِنْهُ وَلَيْسَ مَعَهُ شَىْءٌ ‏"‏‏.‏\hadithno{1448}\hadithtrans{Narrated Anas:Abu Bakr wrote to me what Allah had instructed His Apostle (ﷺ) to do regarding the one who had to pay one Bint Makhad (i.e. one year-old she-camel) as Zakat, and he did not have it but had got Bint Labun (two year old she-camel). (He wrote that) it could be accepted from him as Zakat, and the collector of Zakat would return him 20 Dirhams or two sheep; and if the Zakat payer had not a Bint Makhad, but he had Ibn Labun (a two year old he-camel) then it could be accepted as his Zakat, but he would not be paid anything}}
\hadithdefcmd{bukhari}{1449}{حَدَّثَنَا مُؤَمَّلٌ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، قَالَ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ أَشْهَدُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَصَلَّى قَبْلَ الْخُطْبَةِ، فَرَأَى أَنَّهُ لَمْ يُسْمِعِ النِّسَاءَ، فَأَتَاهُنَّ وَمَعَهُ بِلاَلٌ نَاشِرَ ثَوْبِهِ فَوَعَظَهُنَّ، وَأَمَرَهُنَّ أَنْ يَتَصَدَّقْنَ، فَجَعَلَتِ الْمَرْأَةُ تُلْقِي، وَأَشَارَ أَيُّوبُ إِلَى أُذُنِهِ وَإِلَى حَلْقِهِ‏.‏\hadithno{1449}\hadithtrans{Narrated Ibn `Abbas:I am a witness that Allah's Messenger (ﷺ) offered the Id prayer before delivering the sermon and then he thought that the women would not be able to hear him (because of the distance), so he went to them along with Bilal who was spreading his garment. The Prophet (ﷺ) advised and ordered them to give in charity. So the women started giving their ornaments (in charity). (The sub-narrator Aiyub pointed towards his ears and neck meaning that they gave ornaments from those places such as earrings and necklaces)}}
\hadithdefcmd{bukhari}{1450}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي ثُمَامَةُ، أَنَّ أَنَسًا ـ رضى الله عنه ـ حَدَّثَهُ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ كَتَبَ لَهُ الَّتِي فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَلاَ يُجْمَعُ بَيْنَ مُتَفَرِّقٍ، وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ، خَشْيَةَ الصَّدَقَةِ ‏"‏‏.‏\hadithno{1450}\hadithtrans{Narrated Anas:Abu Bakr wrote to me what was made compulsory by Allah's Messenger (ﷺ) and that was (regarding the payments of Zakat): Neither the property of different people may be taken together nor the joint property may be split for fear of (paying more, or receiving less) Zakat}}
\hadithdefcmd{bukhari}{1451}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي ثُمَامَةُ، أَنَّ أَنَسًا، حَدَّثَهُ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ كَتَبَ لَهُ الَّتِي فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَمَا كَانَ مِنْ خَلِيطَيْنِ فَإِنَّهُمَا يَتَرَاجَعَانِ بَيْنَهُمَا بِالسَّوِيَّةِ ‏"‏‏.‏\hadithno{1451}\hadithtrans{Narrated Anas:Abu Bakr wrote to me what Allah's Messenger (ﷺ) has made compulsory (regarding Zakat) and this was mentioned in it: If a property is equally owned by two partners, they should pay the combined Zakat and it will be considered that both of them have paid their Zakat equally}}
\hadithdefcmd{bukhari}{1452}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ أَعْرَابِيًّا سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْهِجْرَةِ فَقَالَ ‏"‏ وَيْحَكَ، إِنَّ شَأْنَهَا شَدِيدٌ، فَهَلْ لَكَ مِنْ إِبِلٍ تُؤَدِّي صَدَقَتَهَا ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَاعْمَلْ مِنْ وَرَاءِ الْبِحَارِ فَإِنَّ اللَّهَ لَنْ يَتِرَكَ مِنْ عَمَلِكَ شَيْئًا ‏"‏‏.‏\hadithno{1452}\hadithtrans{Narrated Abu Sa`id Al-Khudri:A Bedouin asked Allah's Messenger (ﷺ) about the emigration. The Prophet (ﷺ) said, "May Allah have mercy on you! The matter of emigration is very hard. Have you got camels? Do you pay their Zakat?" The Bedouin said, "Yes, I have camels and I pay their Zakat." The Prophet (ﷺ) said, Work beyond the seas and Allah will not decrease (waste) any of your good deeds." (See Hadith No. 260 Vol)}}
\hadithdefcmd{bukhari}{1453}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي ثُمَامَةُ، أَنَّ أَنَسًا ـ رضى الله عنه ـ حَدَّثَهُ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ كَتَبَ لَهُ فَرِيضَةَ الصَّدَقَةِ الَّتِي أَمَرَ اللَّهُ رَسُولَهُ صلى الله عليه وسلم ‏ "‏ مَنْ بَلَغَتْ عِنْدَهُ مِنَ الإِبِلِ صَدَقَةُ الْجَذَعَةِ، وَلَيْسَتْ عِنْدَهُ جَذَعَةٌ وَعِنْدَهُ حِقَّةٌ، فَإِنَّهَا تُقْبَلُ مِنْهُ الْحِقَّةُ وَيَجْعَلُ مَعَهَا شَاتَيْنِ إِنِ اسْتَيْسَرَتَا لَهُ أَوْ عِشْرِينَ دِرْهَمًا، وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْحِقَّةِ وَلَيْسَتْ عِنْدَهُ الْحِقَّةُ وَعِنْدَهُ الْجَذَعَةُ، فَإِنَّهَا تُقْبَلُ مِنْهُ الْجَذَعَةُ، وَيُعْطِيهِ الْمُصَدِّقُ عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ، وَمَنْ بَلَغَتْ عِنْدَهُ صَدَقَةُ الْحِقَّةِ وَلَيْسَتْ عِنْدَهُ إِلاَّ بِنْتُ لَبُونٍ فَإِنَّهَا تُقْبَلُ مِنْهُ بِنْتُ لَبُونٍ، وَيُعْطِي شَاتَيْنِ أَوْ عِشْرِينَ دِرْهَمًا، وَمَنْ بَلَغَتْ صَدَقَتُهُ بِنْتَ لَبُونٍ وَعِنْدَهُ حِقَّةٌ فَإِنَّهَا تُقْبَلُ مِنْهُ الْحِقَّةُ وَيُعْطِيهِ الْمُصَدِّقُ عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ، وَمَنْ بَلَغَتْ صَدَقَتُهُ بِنْتَ لَبُونٍ وَلَيْسَتْ عِنْدَهُ وَعِنْدَهُ بِنْتُ مَخَاضٍ، فَإِنَّهَا تُقْبَلُ مِنْهُ بِنْتُ مَخَاضٍ وَيُعْطِي مَعَهَا عِشْرِينَ دِرْهَمًا أَوْ شَاتَيْنِ ‏"‏‏.‏\hadithno{1453}\hadithtrans{Narrated Anas:Abu Bakr , wrote to me about the Zakat which Allah had ordered His Apostle to observe: Whoever had to pay Jadha (Jadha means a four-year-old she-camel) as Zakat from his herd of camels and he had not got one, and he had Hiqqa (three-year-old she-camel), that Hiqqa should be accepted from him along with two sheep if they were available or twenty Dirhams (one Durham equals about 1/4 Saudi Riyal) and whoever had to pay Hiqqa as Zakat and he had no Hiqqa but had a Jadha, the Jadha should be accepted from him, and the Zakat collector should repay him twenty Dirhams or two sheep; and whoever had to pay Hiqqa as Zakat and he had not got one, but had a Bint Labun (two-year-old she-camel), it should be accepted from him along with two sheep or twenty Dirhams; and whoever had to pay Bint Labun and had a Hiqqa, that Hiqqa should be accepted from him and the Zakat collector should repay him twenty Dirhams or two sheep; and whoever had to pay Bint Labun and he had not got one but had a Bint Makhad (one-year-old she camel), that Bint Makhad should be accepted from him along with twenty Dirhams or two sheep}}
\hadithdefcmd{bukhari}{1454}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُثَنَّى الأَنْصَارِيُّ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي ثُمَامَةُ بْنُ عَبْدِ اللَّهِ بْنِ أَنَسٍ، أَنَّ أَنَسًا، حَدَّثَهُ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ كَتَبَ لَهُ هَذَا الْكِتَابَ لَمَّا وَجَّهَهُ إِلَى الْبَحْرَيْنِ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏ "‏ هَذِهِ فَرِيضَةُ الصَّدَقَةِ الَّتِي فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمُسْلِمِينَ، وَالَّتِي أَمَرَ اللَّهُ بِهَا رَسُولَهُ، فَمَنْ سُئِلَهَا مِنَ الْمُسْلِمِينَ عَلَى وَجْهِهَا فَلْيُعْطِهَا، وَمَنْ سُئِلَ فَوْقَهَا فَلاَ يُعْطِ فِي أَرْبَعٍ وَعِشْرِينَ مِنَ الإِبِلِ فَمَا دُونَهَا مِنَ الْغَنَمِ مِنْ كُلِّ خَمْسٍ شَاةٌ، إِذَا بَلَغَتْ خَمْسًا وَعِشْرِينَ إِلَى خَمْسٍ وَثَلاَثِينَ فَفِيهَا بِنْتُ مَخَاضٍ أُنْثَى، فَإِذَا بَلَغَتْ سِتًّا وَثَلاَثِينَ إِلَى خَمْسٍ وَأَرْبَعِينَ فَفِيهَا بِنْتُ لَبُونٍ أُنْثَى، فَإِذَا بَلَغَتْ سِتًّا وَأَرْبَعِينَ إِلَى سِتِّينَ فَفِيهَا حِقَّةٌ طَرُوقَةُ الْجَمَلِ، فَإِذَا بَلَغَتْ وَاحِدَةً وَسِتِّينَ إِلَى خَمْسٍ وَسَبْعِينَ فَفِيهَا جَذَعَةٌ، فَإِذَا بَلَغَتْ ـ يَعْنِي ـ سِتًّا وَسَبْعِينَ إِلَى تِسْعِينَ فَفِيهَا بِنْتَا لَبُونٍ، فَإِذَا بَلَغَتْ إِحْدَى وَتِسْعِينَ إِلَى عِشْرِينَ وَمِائَةٍ فَفِيهَا حِقَّتَانِ طَرُوقَتَا الْجَمَلِ، فَإِذَا زَادَتْ عَلَى عِشْرِينَ وَمِائَةٍ فَفِي كُلِّ أَرْبَعِينَ بِنْتُ لَبُونٍ، وَفِي كُلِّ خَمْسِينَ حِقَّةٌ، وَمَنْ لَمْ يَكُنْ مَعَهُ إِلاَّ أَرْبَعٌ مِنَ الإِبِلِ فَلَيْسَ فِيهَا صَدَقَةٌ، إِلاَّ أَنْ يَشَاءَ رَبُّهَا، فَإِذَا بَلَغَتْ خَمْسًا مِنَ الإِبِلِ فَفِيهَا شَاةٌ، وَفِي صَدَقَةِ الْغَنَمِ فِي سَائِمَتِهَا إِذَا كَانَتْ أَرْبَعِينَ إِلَى عِشْرِينَ وَمِائَةٍ شَاةٌ، فَإِذَا زَادَتْ عَلَى عِشْرِينَ وَمِائَةٍ إِلَى مِائَتَيْنِ شَاتَانِ، فَإِذَا زَادَتْ عَلَى مِائَتَيْنِ إِلَى ثَلاَثِمِائَةٍ فَفِيهَا ثَلاَثٌ، فَإِذَا زَادَتْ عَلَى ثَلاَثِمِائَةٍ فَفِي كُلِّ مِائَةٍ شَاةٌ، فَإِذَا كَانَتْ سَائِمَةُ الرَّجُلِ نَاقِصَةً مِنْ أَرْبَعِينَ شَاةً وَاحِدَةً فَلَيْسَ فِيهَا صَدَقَةٌ، إِلاَّ أَنْ يَشَاءَ رَبُّهَا، وَفِي الرِّقَةِ رُبْعُ الْعُشْرِ، فَإِنْ لَمْ تَكُنْ إِلاَّ تِسْعِينَ وَمِائَةً فَلَيْسَ فِيهَا شَىْءٌ، إِلاَّ أَنْ يَشَاءَ رَبُّهَا ‏"‏‏.‏\hadithno{1454}\hadithtrans{Narrated Anas:When Abu Bakr; sent me to (collect the Zakat from) Bahrain, he wrote to me the following:-- (In the name of Allah, the Beneficent, the Merciful). These are the orders for compulsory charity (Zakat) which Allah's Messenger (ﷺ) had made obligatory for every Muslim, and which Allah had ordered His Apostle to observe: Whoever amongst the Muslims is asked to pay Zakat accordingly, he should pay it (to the Zakat collector) and whoever is asked more than that (what is specified in this script) he should not pay it; for twenty-four camels or less, sheep are to be paid as Zakat; for every five camels one sheep is to be paid, and if there are between twenty-five to thirty-five camels, one Bint Makhad is to be paid; and if there are between thirty-six to forty-five (camels), one Bint Labun is to be paid; and if there are between forty-six to sixty (camels), one Hiqqa is to be paid; and if the number is between sixty-one to seventy-five (camels), one Jadha is to be paid; and if the number is between seventy-six to ninety (camels), two Bint Labuns are to be paid; and if they are from ninety-one to one-hundredand twenty (camels), two Hiqqas are to be paid; and if they are over one-hundred and-twenty (camels), for every forty (over one-hundred-and-twenty) one Bint Labun is to be paid, and for every fifty camels (over one-hundred-and-twenty) one Hiqqa is to be paid; and who ever has got only four camels, has to pay nothing as Zakat, but if the owner of these four camels wants to give something, he can. If the number of camels increases to five, the owner has to pay one sheep as Zakat. As regards the Zakat for the (flock) of sheep; if they are between forty and one-hundred-and-twenty sheep, one sheep is to be paid; and if they are between one-hundred-and-twenty to two hundred (sheep), two sheep are to be paid; and if they are between two-hundred to three-hundred (sheep), three sheep are to be paid; and for over three-hundred sheep, for every extra hundred sheep, one sheep is to be paid as Zakat. And if somebody has got less than forty sheep, no Zakat is required, but if he wants to give, he can. For silver the Zakat is one-fortieth of the lot (i.e. 2.5%), and if its value is less than two-hundred Dirhams, Zakat is not required, but if the owner wants to pay he can}}
\hadithdefcmd{bukhari}{1455}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي ثُمَامَةُ، أَنَّ أَنَسًا ـ رضى الله عنه ـ حَدَّثَهُ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ كَتَبَ لَهُ ‏\{‏الصَّدَقَةَ‏\}‏ الَّتِي أَمَرَ اللَّهُ رَسُولَهُ صلى الله عليه وسلم ‏ "‏ وَلاَ يُخْرَجُ فِي الصَّدَقَةِ هَرِمَةٌ، وَلاَ ذَاتُ عَوَارٍ، وَلاَ تَيْسٌ، إِلاَّ مَا شَاءَ الْمُصَدِّقُ ‏"‏‏.‏\hadithno{1455}\hadithtrans{Narrated Anas:Abu Bakr wrote to me what Allah had ordered His Apostle (about Zakat) which goes: Neither an old nor a defected animal, nor a male-goat may be taken as Zakat except if the Zakat collector wishes (to take it)}}
\hadithdefcmd{bukhari}{1457}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، ح وَقَالَ اللَّيْثُ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ أَبُو بَكْرٍ ـ رضى الله عنه ـ وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا كَانُوا يُؤَدُّونَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهَا‏.‏ قَالَ عُمَرُ ـ رضى الله عنه ـ فَمَا هُوَ إِلاَّ أَنْ رَأَيْتُ أَنَّ اللَّهَ شَرَحَ صَدْرَ أَبِي بَكْرٍ ـ رضى الله عنه ـ بِالْقِتَالِ، فَعَرَفْتُ أَنَّهُ الْحَقُّ‏.‏\hadithno{1457}\hadithtrans{Narrated Abu Huraira:Abu Bakr said, "By Allah! If they (pay me the Zakat and) withhold even a young (female) goat which they used to pay during the lifetime of Allah's Messenger (ﷺ), I will fight with them for it." `Umar said, "It was nothing but Allah Who opened Abu Bakr's chest towards the decision to fight, and I came to know that his decision was right}}
\hadithdefcmd{bukhari}{1458}{حَدَّثَنَا أُمَيَّةُ بْنُ بِسْطَامٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا رَوْحُ بْنُ الْقَاسِمِ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا بَعَثَ مُعَاذًا ـ رضى الله عنه ـ عَلَى الْيَمَنِ قَالَ ‏ "‏ إِنَّكَ تَقْدَمُ عَلَى قَوْمٍ أَهْلِ كِتَابٍ، فَلْيَكُنْ أَوَّلَ مَا تَدْعُوهُمْ إِلَيْهِ عِبَادَةُ اللَّهِ، فَإِذَا عَرَفُوا اللَّهَ فَأَخْبِرْهُمْ أَنَّ اللَّهَ قَدْ فَرَضَ عَلَيْهِمْ خَمْسَ صَلَوَاتٍ فِي يَوْمِهِمْ وَلَيْلَتِهِمْ، فَإِذَا فَعَلُوا، فَأَخْبِرْهُمْ أَنَّ اللَّهَ فَرَضَ عَلَيْهُمْ زَكَاةً ‏\{‏تُؤْخَذُ‏\}‏ مِنْ أَمْوَالِهِمْ وَتُرَدُّ عَلَى فُقَرَائِهِمْ، فَإِذَا أَطَاعُوا بِهَا فَخُذْ مِنْهُمْ، وَتَوَقَّ كَرَائِمَ أَمْوَالِ النَّاسِ ‏"‏‏.‏\hadithno{1458}\hadithtrans{Narrated Ibn `Abbas:When Allah's Messenger (ﷺ) sent Mu`adh to Yemen, he said (to him), "YOU are going to people of a (Divine) Book. First of all invite them to worship Allah (alone) and when they come to know Allah, inform them that Allah has enjoined on them, five prayers in every day and night; and if they start offering these prayers, inform them that Allah has enjoined on them, the Zakat. And it is to be taken from the rich amongst them and given to the poor amongst them; and if they obey you in that, take Zakat from them and avoid (don't take) the best property of the people as Zakat}}
\hadithdefcmd{bukhari}{1459}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ الْمَازِنِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ مِنَ التَّمْرِ صَدَقَةٌ، وَلَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ مِنَ الْوَرِقِ صَدَقَةٌ، وَلَيْسَ فِيمَا دُونَ خَمْسِ ذَوْدٍ مِنَ الإِبِلِ صَدَقَةٌ ‏"‏‏.‏\hadithno{1459}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "No Zakat is imposed on less than five Awsuq of dates; no Zakat is imposed on less than five Awaq of silver, and no Zakat is imposed on less than five camels}}
\hadithdefcmd{bukhari}{1460}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ قَالَ انْتَهَيْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ ـ أَوْ وَالَّذِي لاَ إِلَهَ غَيْرُهُ، أَوْ كَمَا حَلَفَ ـ مَا مِنْ رَجُلٍ تَكُونُ لَهُ إِبِلٌ أَوْ بَقَرٌ أَوْ غَنَمٌ لاَ يُؤَدِّي حَقَّهَا إِلاَّ أُتِيَ بِهَا يَوْمَ الْقِيَامَةِ أَعْظَمَ مَا تَكُونُ وَأَسْمَنَهُ، تَطَؤُهُ بِأَخْفَافِهَا، وَتَنْطَحُهُ بِقُرُونِهَا، كُلَّمَا جَازَتْ أُخْرَاهَا رُدَّتْ عَلَيْهِ أُولاَهَا، حَتَّى يُقْضَى بَيْنَ النَّاسِ ‏"‏‏.‏ رَوَاهُ بُكَيْرٌ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1460}\hadithtrans{Narrated Abu Dhar:Once I went to him (the Prophet (ﷺ) ) and he said, "By Allah in Whose Hands my life is (or probably said, 'By Allah, except Whom none has the right to be worshipped) whoever had camels or cows or sheep and did not pay their Zakat, those animals will be brought on the Day of Resurrection far bigger and fatter than before and they will tread him under their hooves, and will butt him with their horns, and (those animals will come in circle): When the last does its turn, the first will start again, and this punishment will go on till Allah has finished the judgments amongst the people}}
\hadithdefcmd{bukhari}{1461}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ كَانَ أَبُو طَلْحَةَ أَكْثَرَ الأَنْصَارِ بِالْمَدِينَةِ مَالاً مِنْ نَخْلٍ، وَكَانَ أَحَبَّ أَمْوَالِهِ إِلَيْهِ بَيْرُحَاءَ وَكَانَتْ مُسْتَقْبِلَةَ الْمَسْجِدِ، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُهَا وَيَشْرَبُ مِنْ مَاءٍ فِيهَا طَيِّبٍ قَالَ أَنَسٌ فَلَمَّا أُنْزِلَتْ هَذِهِ الآيَةُ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ قَامَ أَبُو طَلْحَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ‏.‏ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ وَإِنَّ أَحَبَّ أَمْوَالِي إِلَىَّ بَيْرُحَاءَ، وَإِنَّهَا صَدَقَةٌ لِلَّهِ أَرْجُو بِرَّهَا وَذُخْرَهَا عِنْدَ اللَّهِ، فَضَعْهَا يَا رَسُولَ اللَّهِ حَيْثُ أَرَاكَ اللَّهُ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَخْ، ذَلِكَ مَالٌ رَابِحٌ، ذَلِكَ مَالٌ رَابِحٌ، وَقَدْ سَمِعْتُ مَا قُلْتَ وَإِنِّي أَرَى أَنْ تَجْعَلَهَا فِي الأَقْرَبِينَ ‏"‏‏.‏ فَقَالَ أَبُو طَلْحَةَ أَفْعَلُ يَا رَسُولَ اللَّهِ‏.‏ فَقَسَمَهَا أَبُو طَلْحَةَ فِي أَقَارِبِهِ وَبَنِي عَمِّهِ‏.‏ تَابَعَهُ رَوْحٌ‏.‏ وَقَالَ يَحْيَى بْنُ يَحْيَى وَإِسْمَاعِيلُ عَنْ مَالِكٍ رَايِحٌ‏.‏\hadithno{1461}\hadithtrans{Narrated 'Is-haq bin `Abdullah bin Abi Talha:I heard Anas bin Malik saying, "Abu Talha had more property of date-palm trees gardens than any other amongst the Ansar in Medina and the most beloved of them to him was Bairuha garden, and it was in front of the Mosque of the Prophet (ﷺ) . Allah's Messenger (ﷺ) used to go there and used to drink its nice water." Anas added, "When these verses were revealed:--'By no means shall you Attain righteousness unless You spend (in charity) of that Which you love. ' (3.92) Abu Talha said to Allah's Messenger (ﷺ) 'O Allah's Messenger (ﷺ)! Allah, the Blessed, the Superior says: By no means shall you attain righteousness, unless you spend (in charity) of that which you love. And no doubt, Bairuha' garden is the most beloved of all my property to me. So I want to give it in charity in Allah's Cause. I expect its reward from Allah. O Allah's Messenger (ﷺ)! Spend it where Allah makes you think it feasible.' On that Allah's Apostle said, 'Bravo! It is useful property. I have heard what you have said (O Abu Talha), and I think it would be proper if you gave it to your Kith and kin.' Abu Talha said, I will do so, O Allah's Apostle.' Then Abu Talha distributed that garden amongst his relatives and his cousins}}
\hadithdefcmd{bukhari}{1462}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي زَيْدٌ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي أَضْحًى أَوْ فِطْرٍ إِلَى الْمُصَلَّى ثُمَّ انْصَرَفَ فَوَعَظَ النَّاسَ وَأَمَرَهُمْ بِالصَّدَقَةِ فَقَالَ ‏"‏ أَيُّهَا النَّاسُ تَصَدَّقُوا ‏"‏‏.‏ فَمَرَّ عَلَى النِّسَاءِ فَقَالَ ‏"‏ يَا مَعْشَرَ النِّسَاءِ تَصَدَّقْنَ، فَإِنِّي رَأَيْتُكُنَّ أَكْثَرَ أَهْلِ النَّارِ ‏"‏‏.‏ فَقُلْنَ وَبِمَ ذَلِكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ تُكْثِرْنَ اللَّعْنَ وَتَكْفُرْنَ الْعَشِيرَ، مَا رَأَيْتُ مِنْ نَاقِصَاتِ عَقْلٍ وَدِينٍ أَذْهَبَ لِلُبِّ الرَّجُلِ الْحَازِمِ مِنْ إِحْدَاكُنَّ يَا مَعْشَرَ النِّسَاءِ ‏"‏‏.‏ ثُمَّ انْصَرَفَ فَلَمَّا صَارَ إِلَى مَنْزِلِهِ جَاءَتْ زَيْنَبُ امْرَأَةُ ابْنِ مَسْعُودٍ تَسْتَأْذِنُ عَلَيْهِ فَقِيلَ يَا رَسُولَ اللَّهِ هَذِهِ زَيْنَبُ فَقَالَ ‏"‏ أَىُّ الزَّيَانِبِ ‏"‏‏.‏ فَقِيلَ امْرَأَةُ ابْنِ مَسْعُودٍ‏.‏ قَالَ ‏"‏ نَعَمِ ائْذَنُوا لَهَا ‏"‏‏.‏ فَأُذِنَ لَهَا قَالَتْ يَا نَبِيَّ اللَّهِ إِنَّكَ أَمَرْتَ الْيَوْمَ بِالصَّدَقَةِ، وَكَانَ عِنْدِي حُلِيٌّ لِي، فَأَرَدْتُ أَنْ أَتَصَدَّقَ بِهِ، فَزَعَمَ ابْنُ مَسْعُودٍ أَنَّهُ وَوَلَدَهُ أَحَقُّ مَنْ تَصَدَّقْتُ بِهِ عَلَيْهِمْ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ صَدَقَ ابْنُ مَسْعُودٍ، زَوْجُكِ وَوَلَدُكِ أَحَقُّ مَنْ تَصَدَّقْتِ بِهِ عَلَيْهِمْ ‏"‏‏.‏\hadithno{1462}\hadithtrans{Narrated Abu Sa`id Al-Khudri:On `Id ul Fitr or `Id ul Adha Allah's Messenger (ﷺ) went out to the Musalla. After finishing the prayer, he delivered the sermon and ordered the people to give alms. He said, "O people! Give alms." Then he went towards the women and said, "O women! Give alms, for I have seen that the majority of the dwellers of Hell-Fire were you (women)." The women asked, "O Allah's Messenger (ﷺ)! What is the reason for it?" He replied, "O women! You curse frequently, and are ungrateful to your husbands. I have not seen anyone more deficient in intelligence and religion than you. O women, some of you can lead a cautious wise man astray." Then he left. And when he reached his house, Zainab, the wife of Ibn Mas`ud, came and asked permission to enter It was said, "O Allah's Messenger (ﷺ)! It is Zainab." He asked, 'Which Zainab?" The reply was that she was the wife of Ibn Mas'ud. He said, "Yes, allow her to enter." And she was admitted. Then she said, "O Prophet of Allah! Today you ordered people to give alms and I had an ornament and intended to give it as alms, but Ibn Mas`ud said that he and his children deserved it more than anybody else." The Prophet (ﷺ) replied, "Ibn Mas`ud had spoken the truth. Your husband and your children had more right to it than anybody else}}
\hadithdefcmd{bukhari}{1463}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ سَمِعْتُ سُلَيْمَانَ بْنَ يَسَارٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ فِي فَرَسِهِ وَغُلاَمِهِ صَدَقَةٌ ‏"‏‏.‏\hadithno{1463}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There is no Zakat either on a horse or a slave belonging to a Muslim}}
\hadithdefcmd{bukhari}{1464}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ خُثَيْمِ بْنِ عِرَاكٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ، حَدَّثَنَا خُثَيْمُ بْنُ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ صَدَقَةٌ فِي عَبْدِهِ وَلاَ فِي فَرَسِهِ ‏"‏‏.‏\hadithno{1464}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "There is no Zakat either on a slave or on a horse belonging to a Muslim}}
\hadithdefcmd{bukhari}{1465}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، حَدَّثَنَا عَطَاءُ بْنُ يَسَارٍ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ يُحَدِّثُ أَنَّ النَّبِيَّ صلى الله عليه وسلم جَلَسَ ذَاتَ يَوْمٍ عَلَى الْمِنْبَرِ وَجَلَسْنَا حَوْلَهُ فَقَالَ ‏"‏ إِنِّي مِمَّا أَخَافُ عَلَيْكُمْ مِنْ بَعْدِي مَا يُفْتَحُ عَلَيْكُمْ مِنْ زَهْرَةِ الدُّنْيَا وَزِينَتِهَا ‏"‏‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَوَيَأْتِي الْخَيْرُ بِالشَّرِّ فَسَكَتَ النَّبِيُّ صلى الله عليه وسلم فَقِيلَ لَهُ مَا شَأْنُكَ تُكَلِّمُ النَّبِيَّ صلى الله عليه وسلم وَلاَ يُكَلِّمُكَ فَرَأَيْنَا أَنَّهُ يُنْزَلُ عَلَيْهِ‏.‏ قَالَ ـ فَمَسَحَ عَنْهُ الرُّحَضَاءَ فَقَالَ ‏"‏ أَيْنَ السَّائِلُ ‏"‏ وَكَأَنَّهُ حَمِدَهُ‏.‏ فَقَالَ ‏"‏ إِنَّهُ لاَ يَأْتِي الْخَيْرُ بِالشَّرِّ، وَإِنَّ مِمَّا يُنْبِتُ الرَّبِيعُ يَقْتُلُ أَوْ يُلِمُّ إِلاَّ آكِلَةَ الْخَضْرَاءِ، أَكَلَتْ حَتَّى إِذَا امْتَدَّتْ خَاصِرَتَاهَا اسْتَقْبَلَتْ عَيْنَ الشَّمْسِ، فَثَلَطَتْ وَبَالَتْ وَرَتَعَتْ، وَإِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ، فَنِعْمَ صَاحِبُ الْمُسْلِمِ مَا أَعْطَى مِنْهُ الْمِسْكِينَ وَالْيَتِيمَ وَابْنَ السَّبِيلِ ـ أَوْ كَمَا قَالَ النَّبِيُّ صلى الله عليه وسلم ـ وَإِنَّهُ مَنْ يَأْخُذُهُ بِغَيْرِ حَقِّهِ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ، وَيَكُونُ شَهِيدًا عَلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{1465}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Once the Prophet (ﷺ) sat on a pulpit and we sat around him. Then he said, "The things I am afraid of most for your sake (concerning what will befall you after me) is the pleasures and splendors of the world and its beauties which will be disclosed to you." Somebody said, "O Allah's Messenger (ﷺ)! Can the good bring forth evil?" The Prophet (ﷺ) remained silent for a while. It was said to that person, "What is wrong with you? You are talking to the Prophet (ﷺ) while he is not talking to you." Then we noticed that he was being inspired divinely. Then the Prophet (ﷺ) wiped off his sweat and said, "Where is the questioner?" It seemed as if the Prophet (ﷺ) liked his question. Then he said, "Good never brings forth evil. Indeed it is like what grows on the banks of a water-stream which either kill or make the animals sick, except if an animal eats its fill the Khadira (a kind of vegetable) and then faces the sun, and then defecates and urinates and grazes again. No doubt this wealth is sweet and green. Blessed is the wealth of a Muslim from which he gives to the poor, the orphans and to needy travelers. (Or the Prophet said something similar to it) No doubt, whoever takes it illegally will be like the one who eats but is never satisfied, and his wealth will be a witness against him on the Day of Resurrection}}
\hadithdefcmd{bukhari}{1466}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي شَقِيقٌ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ فَذَكَرْتُهُ لإِبْرَاهِيمَ فَحَدَّثَنِي إِبْرَاهِيمُ عَنْ أَبِي عُبَيْدَةَ عَنْ عَمْرِو بْنِ الْحَارِثِ عَنْ زَيْنَبَ امْرَأَةِ عَبْدِ اللَّهِ بِمِثْلِهِ سَوَاءً، قَالَتْ كُنْتُ فِي الْمَسْجِدِ فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ تَصَدَّقْنَ وَلَوْ مِنْ حُلِيِّكُنَّ ‏"‏‏.‏ وَكَانَتْ زَيْنَبُ تُنْفِقُ عَلَى عَبْدِ اللَّهِ وَأَيْتَامٍ فِي حَجْرِهَا، قَالَ فَقَالَتْ لِعَبْدِ اللَّهِ سَلْ رَسُولَ اللَّهِ صلى الله عليه وسلم أَيَجْزِي عَنِّي أَنْ أُنْفِقَ عَلَيْكَ وَعَلَى أَيْتَامِي فِي حَجْرِي مِنَ الصَّدَقَةِ فَقَالَ سَلِي أَنْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم‏.‏ فَانْطَلَقْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم‏.‏ فَوَجَدْتُ امْرَأَةً مِنَ الأَنْصَارِ عَلَى الْبَابِ، حَاجَتُهَا مِثْلُ حَاجَتِي، فَمَرَّ عَلَيْنَا بِلاَلٌ فَقُلْنَا سَلِ النَّبِيَّ صلى الله عليه وسلم أَيَجْزِي عَنِّي أَنْ أُنْفِقَ عَلَى زَوْجِي وَأَيْتَامٍ لِي فِي حَجْرِي وَقُلْنَا لاَ تُخْبِرْ بِنَا‏.‏ فَدَخَلَ فَسَأَلَهُ فَقَالَ ‏"‏ مَنْ هُمَا ‏"‏‏.‏ قَالَ زَيْنَبُ قَالَ ‏"‏ أَىُّ الزَّيَانِبِ ‏"‏‏.‏ قَالَ امْرَأَةُ عَبْدِ اللَّهِ‏.‏ قَالَ ‏"‏ نَعَمْ لَهَا أَجْرَانِ أَجْرُ الْقَرَابَةِ وَأَجْرُ الصَّدَقَةِ ‏"‏‏.‏\hadithno{1466}\hadithtrans{Narrated `Amr bin Al-Harith:Zainab, the wife of `Abdullah said, "I was in the Mosque and saw the Prophet (ﷺ) saying, 'O women ! Give alms even from your ornaments.' " Zainab used to provide for `Abdullah and those orphans who were under her protection. So she said to `Abdullah, "Will you ask Allah's Messenger (ﷺ) whether it will be sufficient for me to spend part of the Zakat on you and the orphans who are under my protection?" He replied "Will you yourself ask Allah's Messenger (ﷺ) ?" (Zainab added): So I went to the Prophet and I saw there an Ansari woman who was standing at the door (of the Prophet (ﷺ) ) with a similar problem as mine. Bilal passed by us and we asked him, 'Ask the Prophet (ﷺ) whether it is permissible for me to spend (the Zakat) on my husband and the orphans under my protection.' And we requested Bilal not to inform the Prophet (ﷺ) about us. So Bilal went inside and asked the Prophet (ﷺ) regarding our problem. The Prophet (ﷺ) asked, "Who are those two?" Bilal replied that she was Zainab. The Prophet (ﷺ) said, "Which Zainab?" Bilal said, "The wife of `Abdullah (bin Mas`ud)." The Prophet said, "Yes, (it is sufficient for her) and she will receive a double reward (for that): One for helping relatives, and the other for giving Zakat}}
\hadithdefcmd{bukhari}{1467}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ ابْنَةِ أُمِّ سَلَمَةَ، ‏\{‏عَنْ أُمِّ سَلَمَةَ،‏\}‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَلِيَ أَجْرٌ أَنْ أُنْفِقَ عَلَى بَنِي أَبِي سَلَمَةَ إِنَّمَا هُمْ بَنِيَّ‏.‏ فَقَالَ ‏ "‏ أَنْفِقِي عَلَيْهِمْ، فَلَكِ أَجْرُ مَا أَنْفَقْتِ عَلَيْهِمْ ‏"‏‏.‏\hadithno{1467}\hadithtrans{Narrated Zainab:(the daughter of Um Salama) My mother said, "O Allah's Messenger (ﷺ)! Shall I receive a reward if I spend for the sustenance of Abu Salama's offspring, and in fact they are also my sons?" The Prophet (ﷺ) replied, "Spend on them and you will get a reward for what you spend on them}}
\hadithdefcmd{bukhari}{1468}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالصَّدَقَةِ فَقِيلَ مَنَعَ ابْنُ جَمِيلٍ وَخَالِدُ بْنُ الْوَلِيدِ وَعَبَّاسُ بْنُ عَبْدِ الْمُطَّلِبِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَا يَنْقِمُ ابْنُ جَمِيلٍ إِلاَّ أَنَّهُ كَانَ فَقِيرًا فَأَغْنَاهُ اللَّهُ وَرَسُولُهُ، وَأَمَّا خَالِدٌ فَإِنَّكُمْ تَظْلِمُونَ خَالِدًا، قَدِ احْتَبَسَ أَدْرَاعَهُ وَأَعْتُدَهُ فِي سَبِيلِ اللَّهِ، وَأَمَّا الْعَبَّاسُ بْنُ عَبْدِ الْمُطَّلِبِ فَعَمُّ رَسُولِ اللَّهِ صلى الله عليه وسلم فَهْىَ عَلَيْهِ صَدَقَةٌ وَمِثْلُهَا مَعَهَا ‏"‏‏.‏ تَابَعَهُ ابْنُ أَبِي الزِّنَادِ عَنْ أَبِيهِ‏.‏ وَقَالَ ابْنُ إِسْحَاقَ عَنْ أَبِي الزِّنَادِ هِيَ عَلَيْهِ وَمِثْلُهَا مَعَهَا‏.‏ وَقَالَ ابْنُ جُرَيْجٍ حُدِّثْتُ عَنِ الأَعْرَجِ بِمِثْلِهِ‏.‏\hadithno{1468}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) ordered (a person) to collect Zakat, and that person returned and told him that Ibn Jamil, Khalid bin Al-Walid, and `Abbas bin `Abdul Muttalib had refused to give Zakat." The Prophet said, "What made Ibn Jamil refuse to give Zakat though he was a poor man, and was made wealthy by Allah and His Apostle ? But you are unfair in asking Zakat from Khalid as he is keeping his armor for Allah's Cause (for Jihad). As for `Abbas bin `Abdul Muttalib, he is the uncle of Allah's Apostle (ﷺ) and Zakat is compulsory on him and he should pay it double}}
\hadithdefcmd{bukhari}{1469}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ نَاسًا مِنَ الأَنْصَارِ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَاهُمْ، ثُمَّ سَأَلُوهُ فَأَعْطَاهُمْ، حَتَّى نَفِدَ مَا عِنْدَهُ فَقَالَ ‏ "‏ مَا يَكُونُ عِنْدِي مِنْ خَيْرٍ فَلَنْ أَدَّخِرَهُ عَنْكُمْ، وَمَنْ يَسْتَعْفِفْ يُعِفَّهُ اللَّهُ، وَمَنْ يَسْتَغْنِ يُغْنِهِ اللَّهُ، وَمَنْ يَتَصَبَّرْ يُصَبِّرْهُ اللَّهُ، وَمَا أُعْطِيَ أَحَدٌ عَطَاءً خَيْرًا وَأَوْسَعَ مِنَ الصَّبْرِ ‏"‏‏.‏\hadithno{1469}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Some Ansari persons asked for (something) from Allah's Messenger (ﷺ) and he gave them. They again asked him for (something) and he again gave them. And then they asked him and he gave them again till all that was with him finished. And then he said "If I had anything. I would not keep it away from you. (Remember) Whoever abstains from asking others, Allah will make him contented, and whoever tries to make himself self-sufficient, Allah will make him self-sufficient. And whoever remains patient, Allah will make him patient. Nobody can be given a blessing better and greater than patience}}
\hadithdefcmd{bukhari}{1470}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَنْ يَأْخُذَ أَحَدُكُمْ حَبْلَهُ فَيَحْتَطِبَ عَلَى ظَهْرِهِ خَيْرٌ لَهُ مِنْ أَنْ يَأْتِيَ رَجُلاً، فَيَسْأَلَهُ، أَعْطَاهُ أَوْ مَنَعَهُ ‏"‏‏.‏\hadithno{1470}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "By Him in Whose Hand my life is, it is better for anyone of you to take a rope and cut the wood (from the forest) and carry it over his back and sell it (as a means of earning his living) rather than to ask a person for something and that person may give him or not}}
\hadithdefcmd{bukhari}{1471}{حَدَّثَنَا مُوسَى، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنِ الزُّبَيْرِ بْنِ الْعَوَّامِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لأَنْ يَأْخُذَ أَحَدُكُمْ حَبْلَهُ فَيَأْتِيَ بِحُزْمَةِ الْحَطَبِ عَلَى ظَهْرِهِ فَيَبِيعَهَا فَيَكُفَّ اللَّهُ بِهَا وَجْهَهُ، خَيْرٌ لَهُ مِنْ أَنْ يَسْأَلَ النَّاسَ أَعْطَوْهُ أَوْ مَنَعُوهُ ‏"‏‏.‏\hadithno{1471}\hadithtrans{Narrated Az-Zubair bin Al-`Awwam:The Prophet (ﷺ) said, "It is better for anyone of you to take a rope (and cut) and bring a bundle of wood (from the forest) over his back and sell it and Allah will save his face (from the Hell-Fire) because of that, rather than to ask the people who may give him or not}}
\hadithdefcmd{bukhari}{1472}{وَحَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ حَكِيمَ بْنَ حِزَامٍ ـ رضى الله عنه ـ قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَانِي، ثُمَّ سَأَلْتُهُ فَأَعْطَانِي، ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ قَالَ ‏ "‏ يَا حَكِيمُ إِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ، فَمَنْ أَخَذَهُ بِسَخَاوَةِ نَفْسٍ بُورِكَ لَهُ فِيهِ، وَمَنْ أَخَذَهُ بِإِشْرَافِ نَفْسٍ لَمْ يُبَارَكْ لَهُ فِيهِ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ، الْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى ‏"‏‏.‏ قَالَ حَكِيمٌ فَقُلْتُ يَا رَسُولَ اللَّهِ وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ أَرْزَأُ أَحَدًا بَعْدَكَ شَيْئًا حَتَّى أُفَارِقَ الدُّنْيَا، فَكَانَ أَبُو بَكْرٍ ـ رضى الله عنه ـ يَدْعُو حَكِيمًا إِلَى الْعَطَاءِ فَيَأْبَى أَنْ يَقْبَلَهُ مِنْهُ، ثُمَّ إِنَّ عُمَرَ ـ رضى الله عنه ـ دَعَاهُ لِيُعْطِيَهُ فَأَبَى أَنْ يَقْبَلَ مِنْهُ شَيْئًا‏.‏ فَقَالَ عُمَرُ إِنِّي أُشْهِدُكُمْ يَا مَعْشَرَ الْمُسْلِمِينَ عَلَى حَكِيمٍ، أَنِّي أَعْرِضُ عَلَيْهِ حَقَّهُ مِنْ هَذَا الْفَىْءِ فَيَأْبَى أَنْ يَأْخُذَهُ‏.‏ فَلَمْ يَرْزَأْ حَكِيمٌ أَحَدًا مِنَ النَّاسِ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى تُوُفِّيَ‏.‏\hadithno{1472}\hadithtrans{Narrated `Urwa bin Az-Zubair and Sa`id bin Al-Musaiyab:Hakim bin Hizam said, "(Once) I asked Allah's Messenger (ﷺ) (for something) and he gave it to me. Again I asked and he gave (it to me). Again I asked and he gave (it to me). And then he said, "O Hakim! This property is like a sweet fresh fruit; whoever takes it without greediness, he is blessed in it, and whoever takes it with greediness, he is not blessed in it, and he is like a person who eats but is never satisfied; and the upper (giving) hand is better than the lower (receiving) hand." Hakim added, "I said to Allah's Messenger (ﷺ) , 'By Him (Allah) Who sent you with the Truth, I shall never accept anything from anybody after you, till I leave this world.' " Then Abu Bakr (during his caliphate) called Hakim to give him his share from the war booty (like the other companions of the Prophet (ﷺ) ), he refused to accept anything. Then `Umar (during his caliphate) called him to give him his share but he refused. On that `Umar said, "O Muslims! I would like you to witness that I offered Hakim his share from this booty and he refused to take it." So Hakim never took anything from anybody after the Prophet (ﷺ) till he died}}
\hadithdefcmd{bukhari}{1473}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ عُمَرَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعْطِينِي الْعَطَاءَ فَأَقُولُ أَعْطِهِ مَنْ هُوَ أَفْقَرُ إِلَيْهِ مِنِّي فَقَالَ ‏ "‏ خُذْهُ، إِذَا جَاءَكَ مِنْ هَذَا الْمَالِ شَىْءٌ، وَأَنْتَ غَيْرُ مُشْرِفٍ وَلاَ سَائِلٍ، فَخُذْهُ، وَمَا لاَ فَلاَ تُتْبِعْهُ نَفْسَكَ ‏"‏‏.‏\hadithno{1473}\hadithtrans{Narrated `Umar:Allah's Messenger (ﷺ) used to give me something but I would say to him, "would you give it to a poorer and more needy one than l?" The Prophet (ﷺ) said to me, "Take it. If you are given something from this property, without asking for it or having greed for it take it; and if not given, do not run for it}}
\hadithdefcmd{bukhari}{1475}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، قَالَ سَمِعْتُ حَمْزَةَ بْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا يَزَالُ الرَّجُلُ يَسْأَلُ النَّاسَ حَتَّى يَأْتِيَ يَوْمَ الْقِيَامَةِ لَيْسَ فِي وَجْهِهِ مُزْعَةُ لَحْمٍ ‏"‏‏.‏ وَقَالَ إِنَّ الشَّمْسَ تَدْنُو يَوْمَ الْقِيَامَةِ حَتَّى يَبْلُغَ الْعَرَقُ نِصْفَ الأُذُنِ، فَبَيْنَا هُمْ كَذَلِكَ اسْتَغَاثُوا بِآدَمَ، ثُمَّ بِمُوسَى، ثُمَّ بِمُحَمَّدٍ صلى الله عليه وسلم ‏"‏‏.‏ وَزَادَ عَبْدُ اللَّهِ حَدَّثَنِي اللَّيْثُ حَدَّثَنِي ابْنُ أَبِي جَعْفَرٍ ‏"‏ فَيَشْفَعُ لِيُقْضَى بَيْنَ الْخَلْقِ، فَيَمْشِي حَتَّى يَأْخُذَ بِحَلْقَةِ الْبَابِ، فَيَوْمَئِذٍ يَبْعَثُهُ اللَّهُ مَقَامًا مَحْمُودًا، يَحْمَدُهُ أَهْلُ الْجَمْعِ كُلُّهُمْ ‏"‏‏.‏ وَقَالَ مُعَلًّى حَدَّثَنَا وُهَيْبٌ، عَنِ النُّعْمَانِ بْنِ رَاشِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ، أَخِي الزُّهْرِيِّ عَنْ حَمْزَةَ، سَمِعَ ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْمَسْأَلَةِ‏.‏\hadithno{1475}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "A man keeps on asking others for something till he comes on the Day of Resurrection without any piece of flesh on his face." The Prophet (ﷺ) added, "On the Day of Resurrection, the Sun will come near (to, the people) to such an extent that the sweat will reach up to the middle of the ears, so, when all the people are in that state, they will ask Adam for help, and then Moses, and then Muhammad (ﷺ) ." The sub-narrator added "Muhammad will intercede with Allah to judge amongst the people. He will proceed on till he will hold the ring of the door (of Paradise) and then Allah will exalt him to Maqam Mahmud (the privilege of intercession, etc.). And all the people of the gathering will send their praises to Allah}}
\hadithdefcmd{bukhari}{1476}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي مُحَمَّدُ بْنُ زِيَادٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ الْمِسْكِينُ الَّذِي تَرُدُّهُ الأُكْلَةُ وَالأُكْلَتَانِ، وَلَكِنِ الْمِسْكِينُ الَّذِي لَيْسَ لَهُ غِنًى وَيَسْتَحْيِي أَوْ لاَ يَسْأَلُ النَّاسَ إِلْحَافًا ‏"‏‏.‏\hadithno{1476}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The poor person is not the one who asks a morsel or two (of meals) from the others, but the poor is the one who has nothing and is ashamed to beg from others}}
\hadithdefcmd{bukhari}{1477}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنِ ابْنِ أَشْوَعَ، عَنِ الشَّعْبِيِّ، حَدَّثَنِي كَاتِبُ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ كَتَبَ مُعَاوِيَةُ إِلَى الْمُغِيرَةِ بْنِ شُعْبَةَ أَنِ اكْتُبْ، إِلَىَّ بِشَىْءٍ سَمِعْتَهُ مِنَ النَّبِيِّ، صلى الله عليه وسلم‏.‏ فَكَتَبَ إِلَيْهِ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ كَرِهَ لَكُمْ ثَلاَثًا قِيلَ وَقَالَ، وَإِضَاعَةَ الْمَالِ، وَكَثْرَةَ السُّؤَالِ ‏"‏‏.‏\hadithno{1477}\hadithtrans{Narrated Ash-Shu`bi:The clerk of Al-Mughira bin Shu`ba narrated, "Muawiya wrote to Al-Mughira bin Shu`ba: Write to me something which you have heard from the Prophet (ﷺ) ." So Al-Mughira wrote: I heard the Prophet saying, "Allah has hated for you three things: -1. Vain talks, (useless talk) that you talk too much or about others. -2. Wasting of wealth (by extravagance) -3. And asking too many questions (in disputed religious matters) or asking others for something (except in great need). (See Hadith No. 591, Vol. Ill)}}
\hadithdefcmd{bukhari}{1478}{حَدَّثَنَا مُحَمَّدُ بْنُ غُرَيْرٍ الزُّهْرِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنْ أَبِيهِ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَامِرُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، قَالَ أَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم رَهْطًا وَأَنَا جَالِسٌ فِيهِمْ قَالَ فَتَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْهُمْ رَجُلاً لَمْ يُعْطِهِ، وَهُوَ أَعْجَبُهُمْ إِلَىَّ، فَقُمْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَارَرْتُهُ فَقُلْتُ مَا لَكَ عَنْ فُلاَنٍ وَاللَّهِ إِنِّي لأُرَاهُ مُؤْمِنًا‏.‏ قَالَ ‏"‏ أَوْ مُسْلِمًا ‏"‏ قَالَ فَسَكَتُّ قَلِيلاً ثُمَّ غَلَبَنِي مَا أَعْلَمُ فِيهِ فَقُلْتُ يَا رَسُولَ اللَّهِ‏.‏ مَا لَكَ عَنْ فُلاَنٍ وَاللَّهِ إِنِّي لأُرَاهُ مُؤْمِنًا‏.‏ قَالَ ‏"‏ أَوْ مُسْلِمًا ‏"‏‏.‏ قَالَ فَسَكَتُّ قَلِيلاً ثُمَّ غَلَبَنِي مَا أَعْلَمُ فِيهِ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا لَكَ عَنْ فُلاَنٍ وَاللَّهِ إِنِّي لأُرَاهُ مُؤْمِنًا‏.‏ قَالَ ‏"‏ أَوْ مُسْلِمًا ـ يَعْنِي فَقَالَ ـ إِنِّي لأُعْطِي الرَّجُلَ وَغَيْرُهُ أَحَبُّ إِلَىَّ مِنْهُ، خَشْيَةَ أَنْ يُكَبَّ فِي النَّارِ عَلَى وَجْهِهِ ‏"‏‏.‏ وَعَنْ أَبِيهِ عَنْ صَالِحٍ عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدٍ أَنَّهُ قَالَ سَمِعْتُ أَبِي يُحَدِّثُ هَذَا فَقَالَ فِي حَدِيثِهِ فَضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ فَجَمَعَ بَيْنَ عُنُقِي وَكَتِفِي ثُمَّ قَالَ ‏"‏ أَقْبِلْ أَىْ سَعْدُ إِنِّي لأُعْطِي الرَّجُلَ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ ‏\{‏فَكُبْكِبُوا‏\}‏ قُلِبُوا ‏\{‏مُكِبًّا‏\}‏ أَكَبَّ الرَّجُلُ إِذَا كَانَ فِعْلُهُ غَيْرَ وَاقِعٍ عَلَى أَحَدٍ، فَإِذَا وَقَعَ الْفِعْلُ قُلْتَ كَبَّهُ اللَّهُ لِوَجْهِهِ، وَكَبَبْتُهُ أَنَا‏.‏\hadithno{1478}\hadithtrans{Narrated Sa`d (bin Abi Waqqas):Allah's Messenger (ﷺ) distributed something (from the resources of Zakat) amongst a group of people while I was sitting amongst them, but he left a man whom I considered the best of the lot. So, I went up to Allah's Messenger (ﷺ) and asked him secretly, "Why have you left that person? By Allah! I consider him a believer." The Prophet (ﷺ) said, "Or merely a Muslim (Who surrender to Allah)." I remained quiet for a while but could not help repeating my question because of what I knew about him. I said, "O Allah's Apostle! Why have you left that person? By Allah! I consider him a believer. " The Prophet (ﷺ) said, "Or merely a Muslim." I remained quiet for a while but could not help repeating my question because of what I knew about him. I said, "O Allah's Messenger (ﷺ)! Why have you left that person? By Allah! I consider him a believer." The Prophet (ﷺ) said, "Or merely a Muslim." Then Allah's Messenger (ﷺ) said, "I give to a person while another is dearer to me, for fear that he may be thrown in the Hell-fire on his face (by reneging from Islam)}}
\hadithdefcmd{bukhari}{1479}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ الْمِسْكِينُ الَّذِي يَطُوفُ عَلَى النَّاسِ تَرُدُّهُ اللُّقْمَةُ وَاللُّقْمَتَانِ وَالتَّمْرَةُ وَالتَّمْرَتَانِ، وَلَكِنِ الْمِسْكِينُ الَّذِي لاَ يَجِدُ غِنًى يُغْنِيهِ، وَلاَ يُفْطَنُ بِهِ فَيُتَصَدَّقُ عَلَيْهِ، وَلاَ يَقُومُ فَيَسْأَلُ النَّاسَ ‏"‏‏.‏\hadithno{1479}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The poor person is not the one who goes round the people and ask them for a mouthful or two (of meals) or a date or two but the poor is that who has not enough (money) to satisfy his needs and whose condition is not known to others, that others may give him something in charity, and who does not beg of people}}
\hadithdefcmd{bukhari}{1480}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا أَبُو صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لأَنْ يَأْخُذَ أَحَدُكُمْ حَبْلَهُ، ثُمَّ يَغْدُوَ ـ أَحْسِبُهُ قَالَ ـ إِلَى الْجَبَلِ فَيَحْتَطِبَ، فَيَبِيعَ فَيَأْكُلَ وَيَتَصَدَّقَ خَيْرٌ لَهُ مِنْ أَنْ يَسْأَلَ النَّاسَ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ صَالِحُ بْنُ كَيْسَانَ أَكْبَرُ مِنَ الزُّهْرِيِّ، وَهُوَ قَدْ أَدْرَكَ ابْنَ عُمَرَ‏.‏\hadithno{1480}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "No doubt, it is better for a person to take a rope and proceed in the morning to the mountains and cut the wood and then sell it, and eat from this income and give alms from it than to ask others for something}}
\hadithdefcmd{bukhari}{1482}{حَدَّثَنَا سَهْلُ بْنُ بَكَّارٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ عَبَّاسٍ السَّاعِدِيِّ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ غَزَوْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم غَزْوَةَ تَبُوكَ فَلَمَّا جَاءَ وَادِيَ الْقُرَى إِذَا امْرَأَةٌ فِي حَدِيقَةٍ لَهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ اخْرُصُوا ‏"‏‏.‏ وَخَرَصَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَشَرَةَ أَوْسُقٍ فَقَالَ لَهَا ‏"‏ أَحْصِي مَا يَخْرُجُ مِنْهَا ‏"‏‏.‏ فَلَمَّا أَتَيْنَا تَبُوكَ قَالَ ‏"‏ أَمَا إِنَّهَا سَتَهُبُّ اللَّيْلَةَ رِيحٌ شَدِيدَةٌ فَلاَ يَقُومَنَّ أَحَدٌ، وَمَنْ كَانَ مَعَهُ بَعِيرٌ فَلْيَعْقِلْهُ ‏"‏‏.‏ فَعَقَلْنَاهَا وَهَبَّتْ رِيحٌ شَدِيدَةٌ فَقَامَ رَجُلٌ فَأَلْقَتْهُ بِجَبَلِ طَيِّئٍ ـ وَأَهْدَى مَلِكُ أَيْلَةَ لِلنَّبِيِّ صلى الله عليه وسلم بَغْلَةً بَيْضَاءَ، وَكَسَاهُ بُرْدًا وَكَتَبَ لَهُ بِبَحْرِهِمْ ـ فَلَمَّا أَتَى وَادِيَ الْقُرَى قَالَ لِلْمَرْأَةِ ‏"‏ كَمْ جَاءَ حَدِيقَتُكِ ‏"‏‏.‏ قَالَتْ عَشَرَةَ أَوْسُقٍ خَرْصَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي مُتَعَجِّلٌ إِلَى الْمَدِينَةِ، فَمَنْ أَرَادَ مِنْكُمْ أَنْ يَتَعَجَّلَ مَعِي فَلْيَتَعَجَّلْ ‏"‏‏.‏ فَلَمَّا ـ قَالَ ابْنُ بَكَّارٍ كَلِمَةً مَعْنَاهَا ـ أَشْرَفَ عَلَى الْمَدِينَةِ قَالَ ‏"‏ هَذِهِ طَابَةُ ‏"‏‏.‏ فَلَمَّا رَأَى أُحُدًا قَالَ ‏"‏ هَذَا جُبَيْلٌ يُحِبُّنَا وَنُحِبُّهُ، أَلاَ أُخْبِرُكُمْ بِخَيْرِ دُورِ الأَنْصَارِ ‏"‏‏.‏ قَالُوا بَلَى‏.‏ قَالَ ‏"‏ دُورُ بَنِي النَّجَّارِ، ثُمَّ دُورُ بَنِي عَبْدِ الأَشْهَلِ، ثُمَّ دُورُ بَنِي سَاعِدَةَ، أَوْ دُورُ بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ، وَفِي كُلِّ دُورِ الأَنْصَارِ ـ يَعْنِي ـ خَيْرًا ‏"‏‏.‏ وَقَالَ سُلَيْمَانُ بْنُ بِلاَلٍ حَدَّثَنِي عَمْرٌو، ‏"‏ ثُمَّ دَارُ بَنِي الْحَارِثِ، ثُمَّ بَنِي سَاعِدَةَ ‏"‏‏.‏ وَقَالَ سُلَيْمَانُ عَنْ سَعْدِ بْنِ سَعِيدٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ عَبَّاسٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أُحُدٌ جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ كُلُّ بُسْتَانٍ عَلَيْهِ حَائِطٌ فَهْوَ حَدِيقَةٌ، وَمَا لَمْ يَكُنْ عَلَيْهِ حَائِطٌ لَمْ يَقُلْ حَدِيقَةٌ‏.‏\hadithno{1482}\hadithtrans{Narrated Abu Humaid As-Sa`idi:We took part in the holy battle of Tabuk in the company of the Prophet (ﷺ) and when we arrived at the Wadi-al-Qura, there was a woman in her garden. The Prophet (ﷺ) asked his companions to estimate the amount of the fruits in the garden, and Allah's Messenger (ﷺ) estimated it at ten Awsuq (One Wasaq = 60 Sa's) and 1 Sa'= 3 kg. approximately). The Prophet (ﷺ) said to that lady, "Check what your garden will yield." When we reached Tabuk, the Prophet (ﷺ) said, "There will be a strong wind tonight and so no one should stand and whoever has a camel, should fasten it." So we fastened our camels. A strong wind blew at night and a man stood up and he was blown away to a mountain called Taiy, The King of Aila sent a white mule and a sheet for wearing to the Prophet (ﷺ) as a present, and wrote to the Prophet (ﷺ) that his people would stay in their place (and will pay Jizya taxation.) (1) When the Prophet (ﷺ) reached Wadi-al- Qura he asked that woman how much her garden had yielded. She said, "Ten Awsuq," and that was what Allah's Messenger (ﷺ) had estimated. Then the Prophet (ﷺ) said, "I want to reach Medina quickly, and whoever among you wants to accompany me, should hurry up." The sub-narrator Ibn Bakkar said something which meant: When the Prophet (ﷺ) saw Medina he said, "This is Taba." And when he saw the mountain of Uhud, he said, "This mountain loves us and we love it. Shall I tell you of the best amongst the Ansar?" They replied in the affirmative. He said, "The family of Bani-n-Najjar, and then the family of Bani Sa`ida or Bani Al-Harith bin Al-Khazraj. (The above-mentioned are the best) but there is goodness in all the families of Ansar}}
\hadithdefcmd{bukhari}{1483}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فِيمَا سَقَتِ السَّمَاءُ وَالْعُيُونُ أَوْ كَانَ عَثَرِيًّا الْعُشْرُ، وَمَا سُقِيَ بِالنَّضْحِ نِصْفُ الْعُشْرِ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ هَذَا تَفْسِيرُ الأَوَّلِ لأَنَّهُ لَمْ يُوَقِّتْ فِي الأَوَّلِ ـ يَعْنِي حَدِيثَ ابْنِ عُمَرَ ـ وَفِيمَا سَقَتِ السَّمَاءُ الْعُشْرُ وَبَيَّنَ فِي هَذَا وَوَقَّتَ، وَالزِّيَادَةُ مَقْبُولَةٌ، وَالْمُفَسَّرُ يَقْضِي عَلَى الْمُبْهَمِ إِذَا رَوَاهُ أَهْلُ الثَّبَتِ، كَمَا رَوَى الْفَضْلُ بْنُ عَبَّاسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يُصَلِّ فِي الْكَعْبَةِ‏.‏ وَقَالَ بِلاَلٌ قَدْ صَلَّى‏.‏ فَأُخِذَ بِقَوْلِ بِلاَلٍ وَتُرِكَ قَوْلُ الْفَضْلِ‏.‏\hadithno{1483}\hadithtrans{Narrated Salim bin `Abdullah from his father:The Prophet (ﷺ) said, "On a land irrigated by rain water or by natural water channels or if the land is wet due to a near by water channel Ushr (i.e. one-tenth) is compulsory (as Zakat); and on the land irrigated by the well, half of an Ushr (i.e. one-twentieth) is compulsory (as Zakat on the yield of the land)}}
\hadithdefcmd{bukhari}{1484}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا مَالِكٌ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لَيْسَ فِيمَا أَقَلُّ مِنْ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ، وَلاَ فِي أَقَلَّ مِنْ خَمْسَةٍ مِنَ الإِبِلِ الذَّوْدِ صَدَقَةٌ، وَلاَ فِي أَقَلَّ مِنْ خَمْسِ أَوَاقٍ مِنَ الْوَرِقِ صَدَقَةٌ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ هَذَا تَفْسِيرُ الأَوَّلِ إِذَا قَالَ ‏"‏ لَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ ‏"‏‏.‏ وَيُؤْخَذُ أَبَدًا فِي الْعِلْمِ بِمَا زَادَ أَهْلُ الثَّبَتِ أَوْ بَيَّنُوا‏.‏\hadithno{1484}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "There is no Zakat on less than five Awsuq (of dates), or on less than five camels, or on less than five Awaq of silver}}
\hadithdefcmd{bukhari}{1485}{حَدَّثَنَا عُمَرُ بْنُ مُحَمَّدِ بْنِ الْحَسَنِ الأَسَدِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُؤْتَى بِالتَّمْرِ عِنْدَ صِرَامِ النَّخْلِ فَيَجِيءُ هَذَا بِتَمْرِهِ وَهَذَا مِنْ تَمْرِهِ حَتَّى يَصِيرَ عِنْدَهُ كَوْمًا مِنْ تَمْرٍ، فَجَعَلَ الْحَسَنُ وَالْحُسَيْنُ ـ رضى الله عنهما ـ يَلْعَبَانِ بِذَلِكَ التَّمْرِ، فَأَخَذَ أَحَدُهُمَا تَمْرَةً، فَجَعَلَهَا فِي فِيهِ، فَنَظَرَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْرَجَهَا مِنْ فِيهِ فَقَالَ ‏ "‏ أَمَا عَلِمْتَ أَنَّ آلَ مُحَمَّدٍ صلى الله عليه وسلم لاَ يَأْكُلُونَ الصَّدَقَةَ ‏"‏‏.‏\hadithno{1485}\hadithtrans{Narrated Abu Huraira:Dates used to be brought to Allah's Messenger (ﷺ) immediately after being plucked. Different persons would bring their dates till a big heap collected (in front of the Prophet). Once Al-Hasan and Al-Husain were playing with these dates. One of them took a date and put it in his mouth. Allah's Messenger (ﷺ) looked at him and took it out from his mouth and said, "Don't you know that Muhammad's offspring do not eat what is given in charity?}}
\hadithdefcmd{bukhari}{1486}{حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ الثَّمَرَةِ حَتَّى يَبْدُوَ صَلاَحُهَا‏.‏ وَكَانَ إِذَا سُئِلَ عَنْ صَلاَحِهَا قَالَ حَتَّى تَذْهَبَ عَاهَتُهُ‏.‏\hadithno{1486}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) had forbidden the sale of dates till they were good (ripe), and when it was asked what it meant, the Prophet (ﷺ) said, "Till there is no danger of blight}}
\hadithdefcmd{bukhari}{1487}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنِي اللَّيْثُ، حَدَّثَنِي خَالِدُ بْنُ يَزِيدَ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ‏.‏ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ الثِّمَارِ حَتَّى يَبْدُوَ صَلاَحُهَا‏.‏\hadithno{1487}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) had forbidden the sale of fruits till they were ripe (free from blight)}}
\hadithdefcmd{bukhari}{1488}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثِّمَارِ حَتَّى تُزْهِيَ، قَالَ حَتَّى تَحْمَارَّ‏.‏\hadithno{1488}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) forbade the selling of fruits until they were ripe. The Prophet (ﷺ) added, "It means that they become red}}
\hadithdefcmd{bukhari}{1489}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ يُحَدِّثُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ تَصَدَّقَ بِفَرَسٍ فِي سَبِيلِ اللَّهِ فَوَجَدَهُ يُبَاعُ، فَأَرَادَ أَنْ يَشْتَرِيَهُ، ثُمَّ أَتَى النَّبِيَّ صلى الله عليه وسلم فَاسْتَأْمَرَهُ فَقَالَ ‏ "‏ لاَ تَعُدْ فِي صَدَقَتِكَ ‏"‏ فَبِذَلِكَ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ لاَ يَتْرُكُ أَنْ يَبْتَاعَ شَيْئًا تَصَدَّقَ بِهِ إِلاَّ جَعَلَهُ صَدَقَةً‏.‏\hadithno{1489}\hadithtrans{Narrated `Abdullah bin `Umar:`Umar bin Al-Khattab gave a horse in charity in Allah's Cause and later he saw it being sold in the market and intended to purchase it. Then he went to the Prophet (ﷺ) and asked his permission. The Prophet said, "Do not take back what you have given in charity." For this reason, Ibn `Umar never purchased the things which he had given in charity, and in case he had purchased something (unknowingly) he would give it in charity again}}
\hadithdefcmd{bukhari}{1490}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُمَرَ ـ رضى الله عنه ـ يَقُولُ حَمَلْتُ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ، فَأَضَاعَهُ الَّذِي كَانَ عِنْدَهُ، فَأَرَدْتُ أَنْ أَشْتَرِيَهُ، وَظَنَنْتُ أَنَّهُ يَبِيعُهُ بِرُخْصٍ، فَسَأَلْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَشْتَرِ وَلاَ تَعُدْ فِي صَدَقَتِكَ، وَإِنْ أَعْطَاكَهُ بِدِرْهَمٍ، فَإِنَّ الْعَائِدَ فِي صَدَقَتِهِ كَالْعَائِدِ فِي قَيْئِهِ ‏"‏‏.‏\hadithno{1490}\hadithtrans{Narrated `Umar:Once I gave a horse in Allah's Cause (in charity) but that person did not take care of it. I intended to buy it, as I thought he would sell it at a low price. So, I asked the Prophet (ﷺ) about it. He said, "Neither buy, nor take back your alms which you have given, even if the seller were willing to sell it for one Dirham, for he who takes back his alms is like the one who swallows his own vomit}}
\hadithdefcmd{bukhari}{1491}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أَخَذَ الْحَسَنُ بْنُ عَلِيٍّ ـ رضى الله عنهما ـ تَمْرَةً مِنْ تَمْرِ الصَّدَقَةِ، فَجَعَلَهَا فِي فِيهِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كِخٍ كِخٍ ـ لِيَطْرَحَهَا ثُمَّ قَالَ ـ أَمَا شَعَرْتَ أَنَّا لاَ نَأْكُلُ الصَّدَقَةَ ‏"‏‏.‏\hadithno{1491}\hadithtrans{Narrated Abu Huraira:Al-Hasan bin `Ali took a date from the dates given in charity and put it in his mouth. The Prophet (ﷺ) said, "Expel it from your mouth. Don't you know that we do not eat a thing which is given in charity?}}
\hadithdefcmd{bukhari}{1492}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبِّاسٍ ـ رضى الله عنهما ـ قَالَ وَجَدَ النَّبِيُّ صلى الله عليه وسلم شَاةً مَيِّتَةً أُعْطِيَتْهَا مَوْلاَةٌ لِمَيْمُونَةَ مِنَ الصَّدَقَةِ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلاَّ انْتَفَعْتُمْ بِجِلْدِهَا ‏"‏‏.‏ قَالُوا إِنَّهَا مَيْتَةٌ‏.‏ قَالَ ‏"‏ إِنَّمَا حَرُمَ أَكْلُهَا ‏"‏‏.‏\hadithno{1492}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) saw a dead sheep which had been given in charity to a freed slave-girl of Maimuna, the wife of the Prophet (ﷺ) . The Prophet (ﷺ) said, "Why don't you get the benefit of its hide?" They said, "It is dead." He replied, "Only to eat (its meat) is illegal}}
\hadithdefcmd{bukhari}{1493}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا الْحَكَمُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا أَرَادَتْ أَنْ تَشْتَرِيَ بَرِيرَةَ لِلْعِتْقِ، وَأَرَادَ مَوَالِيهَا أَنْ يَشْتَرِطُوا وَلاَءَهَا، فَذَكَرَتْ عَائِشَةُ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏"‏ اشْتَرِيهَا، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ قَالَتْ وَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِلَحْمٍ فَقُلْتُ هَذَا مَا تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ فَقَالَ ‏"‏ هُوَ لَهَا صَدَقَةٌ، وَلَنَا هَدِيَّةٌ ‏"‏‏.‏\hadithno{1493}\hadithtrans{Narrated Al-Aswad:`Aisha intended to buy Barira (a slave-girl) in order to manumit her and her masters intended to put the condition that her Al-wala would be for them. `Aisha mentioned that to the Prophet (ﷺ) who said to her, "Buy her, as the "Wala" is for the manumitted." Once some meat was presented to the Prophet (ﷺ) and `Aisha said to him, "This (meat) was given in charity to Barira." He said, "It is an object of charity for Barira but a gift for us}}
\hadithdefcmd{bukhari}{1494}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ الأَنْصَارِيَّةِ ـ رضى الله عنها ـ قَالَتْ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى عَائِشَةَ ـ رضى الله عنها ـ فَقَالَ ‏"‏ هَلْ عِنْدَكُمْ شَىْءٌ ‏"‏‏.‏ فَقَالَتْ لاَ‏.‏ إِلاَّ شَىْءٌ بَعَثَتْ بِهِ إِلَيْنَا نُسَيْبَةُ مِنَ الشَّاةِ الَّتِي بَعَثْتَ بِهَا مِنَ الصَّدَقَةِ‏.‏ فَقَالَ ‏"‏ إِنَّهَا قَدْ بَلَغَتْ مَحِلَّهَا ‏"‏‏.‏\hadithno{1494}\hadithtrans{Narrated Um 'Atiyya Al-Ansariya:The Prophet (ﷺ) went to `Aisha and asked her whether she had something (to eat). She replied that she had nothing except the mutton (piece) which Nusaiba (Um 'Atiyya) had sent to us (Barira) in charity." The Prophet (ﷺ) said, "It has reached its place and now it is not a thing of charity but a gift for us}}
\hadithdefcmd{bukhari}{1495}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِلَحْمٍ تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ فَقَالَ ‏ "‏ هُوَ عَلَيْهَا صَدَقَةٌ، وَهُوَ لَنَا هَدِيَّةٌ ‏"‏‏.‏ وَقَالَ أَبُو دَاوُدَ أَنْبَأَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعَ أَنَسًا، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1495}\hadithtrans{Narrated Anas:Some meat was presented to the Prophet (ﷺ) and it had been given to Barira (the freed slave-girl of Aisha) in charity. He said, "This meat is a thing of charity for Barira but it is a gift for us}}
\hadithdefcmd{bukhari}{1496}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ أَبِي مَعْبَدٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمُعَاذِ بْنِ جَبَلٍ حِينَ بَعَثَهُ إِلَى الْيَمَنِ ‏ "‏ إِنَّكَ سَتَأْتِي قَوْمًا أَهْلَ كِتَابٍ، فَإِذَا جِئْتَهُمْ فَادْعُهُمْ إِلَى أَنْ يَشْهَدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ، فَإِنْ هُمْ أَطَاعُوا لَكَ بِذَلِكَ، فَأَخْبِرْهُمْ أَنَّ اللَّهَ قَدْ فَرَضَ عَلَيْهِمْ خَمْسَ صَلَوَاتٍ فِي كُلِّ يَوْمٍ وَلَيْلَةٍ، فَإِنْ هُمْ أَطَاعُوا لَكَ بِذَلِكَ فَأَخْبِرْهُمْ أَنَّ اللَّهَ قَدْ فَرَضَ عَلَيْهِمْ صَدَقَةً تُؤْخَذُ مِنْ أَغْنِيَائِهِمْ فَتُرَدُّ عَلَى فُقَرَائِهِمْ، فَإِنْ هُمْ أَطَاعُوا لَكَ بِذَلِكَ فَإِيَّاكَ وَكَرَائِمَ أَمْوَالِهِمْ، وَاتَّقِ دَعْوَةَ الْمَظْلُومِ، فَإِنَّهُ لَيْسَ بَيْنَهُ وَبَيْنَ اللَّهِ حِجَابٌ ‏"‏‏.‏\hadithno{1496}\hadithtrans{Narrated Abu Ma`bad:(the slave of Ibn `Abbas) Allah's Messenger (ﷺ) said to Mu`adh when he sent him to Yemen, "You will go to the people of the Scripture. So, when you reach there, invite them to testify that none has the right to be worshipped but Allah, and that Muhammad is His Apostle. And if they obey you in that, tell them that Allah has enjoined on them five prayers in each day and night. And if they obey you in that tell them that Allah has made it obligatory on them to pay the Zakat which will be taken from the rich among them and given to the poor among them. If they obey you in that, then avoid taking the best of their possessions, and be afraid of the curse of an oppressed person because there is no screen between his invocation and Allah}}
\hadithdefcmd{bukhari}{1497}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَتَاهُ قَوْمٌ بِصَدَقَتِهِمْ قَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَى آلِ فُلاَنٍ ‏"‏‏.‏ فَأَتَاهُ أَبِي بِصَدَقَتِهِ، فَقَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَى آلِ أَبِي أَوْفَى ‏"‏‏.‏\hadithno{1497}\hadithtrans{Narrated 'Abdullah bin Abu Aufa : Whenever a person came to the Prophet (ﷺ) with his alms, the Prophet (ﷺ) would say, "O Allah! Send your Blessings upon so and so." My father went to the Prophet (ﷺ) with his alms and the Prophet (ﷺ) said, "O Allah! Send your blessings upon the offspring of Abu Aufa}}
\hadithdefcmd{bukhari}{1498}{وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَّ رَجُلاً مِنْ بَنِي إِسْرَائِيلَ سَأَلَ بَعْضَ بَنِي إِسْرَائِيلَ بِأَنْ يُسْلِفَهُ أَلْفَ دِينَارٍ، فَدَفَعَهَا إِلَيْهِ، فَخَرَجَ فِي الْبَحْرِ، فَلَمْ يَجِدْ مَرْكَبًا، فَأَخَذَ خَشَبَةً فَنَقَرَهَا فَأَدْخَلَ فِيهَا أَلْفَ دِينَارٍ، فَرَمَى بِهَا فِي الْبَحْرِ، فَخَرَجَ الرَّجُلُ الَّذِي كَانَ أَسْلَفَهُ، فَإِذَا بِالْخَشَبَةِ فَأَخَذَهَا لأَهْلِهِ حَطَبًا ـ فَذَكَرَ الْحَدِيثَ ـ فَلَمَّا نَشَرَهَا وَجَدَ الْمَالَ ‏"‏‏.‏\hadithno{1498}\hadithtrans{Narrated Abu Huraira The Prophet (ﷺ) said, "A man from Bani Israel asked someone from Bani Israel to give him a loan of one thousand Dinars and the later gave it to him. The debtor went on a voyage (when the time for the payment of the debt became due) but he did not find a boat, so he took a piece of wood and bored it and put 1000 Dinars in it and threw it into the sea. The creditor went out and took the piece of wood to his family to be used as fire-wood." (See Hadith No. 488 B, Vol. 3). And the Prophet (ﷺ) narrated the narration (and said), "When he sawed the wood, he found his money}}
\hadithdefcmd{bukhari}{1499}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَعَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَجْمَاءُ جُبَارٌ، وَالْبِئْرُ جُبَارٌ، وَالْمَعْدِنُ جُبَارٌ، وَفِي الرِّكَازِ الْخُمُسُ ‏"‏‏.‏\hadithno{1499}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There is no compensation for one killed or wounded by an animal or by falling in a well, or because of working in mines; but Khumus is compulsory on Rikaz}}
\hadithdefcmd{bukhari}{1500}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا أَبُو أُسَامَةَ، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ ـ رضى الله عنه ـ قَالَ اسْتَعْمَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً مِنَ الأَسْدِ عَلَى صَدَقَاتِ بَنِي سُلَيْمٍ يُدْعَى ابْنَ اللُّتْبِيَّةِ، فَلَمَّا جَاءَ حَاسَبَهُ‏.‏\hadithno{1500}\hadithtrans{Narrated Abu Humaid Al-Sa`idi:Allah's Messenger (ﷺ) appointed a man called Ibn Al-Lutbiya, from the tribe of Al-Asd to collect Zakat from Bani Sulaim. When he returned, (after collecting the Zakat) the Prophet (ﷺ) checked the account with him}}
\hadithdefcmd{bukhari}{1501}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ نَاسًا، مِنْ عُرَيْنَةَ اجْتَوَوُا الْمَدِينَةَ، فَرَخَّصَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَأْتُوا إِبِلَ الصَّدَقَةِ فَيَشْرَبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا، فَقَتَلُوا الرَّاعِيَ وَاسْتَاقُوا الذَّوْدَ، فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأُتِيَ بِهِمْ، فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَرَ أَعْيُنَهُمْ، وَتَرَكَهُمْ بِالْحَرَّةِ يَعَضُّونَ الْحِجَارَةَ‏.‏ تَابَعَهُ أَبُو قِلاَبَةَ وَحُمَيْدٌ وَثَابِتٌ عَنْ أَنَسٍ‏.‏\hadithno{1501}\hadithtrans{Narrated Anas:Some people from `Uraina tribe came to Medina and its climate did not suit them, so Allah's Messenger (ﷺ) allowed them to go to the herd of camels (given as Zakat) and they drank their milk and urine (as medicine) but they killed the shepherd and drove away all the camels. So Allah's Messenger (ﷺ) sent (men) in their pursuit to catch them, and they were brought, and he had their hands and feet cut, and their eyes were branded with heated pieces of iron and they were left in the Harra (a stony place at Medina) biting the stones. (See Hadith No. 234, Vol)}}
\hadithdefcmd{bukhari}{1502}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا أَبُو عَمْرٍو الأَوْزَاعِيُّ، حَدَّثَنِي إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ قَالَ غَدَوْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِعَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ لِيُحَنِّكَهُ، فَوَافَيْتُهُ فِي يَدِهِ الْمِيسَمُ يَسِمُ إِبِلَ الصَّدَقَةِ‏.‏\hadithno{1502}\hadithtrans{Narrated Anas bin Malik:I took `Abdullah bin Abu Talha to Allah's Messenger (ﷺ) to perform Tahnik for him. (Tahnik was a custom among the Muslims that whenever a child was born they used to take it to the Prophet (ﷺ) who would chew a piece of date and put a part of its juice in the child's mouth). I saw the Prophet (ﷺ) and he had an instrument for branding in his hands and was branding the camels of Zakat}}
\hadithdefcmd{bukhari}{1503}{حَدَّثَنَا يَحْيَى بْنُ مُحَمَّدِ بْنِ السَّكَنِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَهْضَمٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عُمَرَ بْنِ نَافِعٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَكَاةَ الْفِطْرِ صَاعًا مِنْ تَمْرٍ، أَوْ صَاعًا مِنْ شَعِيرٍ عَلَى الْعَبْدِ وَالْحُرِّ، وَالذَّكَرِ وَالأُنْثَى، وَالصَّغِيرِ وَالْكَبِيرِ مِنَ الْمُسْلِمِينَ، وَأَمَرَ بِهَا أَنْ تُؤَدَّى قَبْلَ خُرُوجِ النَّاسِ إِلَى الصَّلاَةِ‏.‏\hadithno{1503}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) enjoined the payment of one Sa' of dates or one Sa' of barley as Zakat-ul-Fitr on every Muslim slave or free, male or female, young or old, and he ordered that it be paid before the people went out to offer the `Id prayer. (One Sa' = 3 Kilograms approx)}}
\hadithdefcmd{bukhari}{1504}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَضَ زَكَاةَ الْفِطْرِ صَاعًا مِنْ تَمْرٍ، أَوْ صَاعًا مِنْ شَعِيرٍ، عَلَى كُلِّ حُرٍّ أَوْ عَبْدٍ، ذَكَرٍ أَوْ أُنْثَى، مِنَ الْمُسْلِمِينَ‏.‏\hadithno{1504}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) made it incumbent on all the slave or free Muslims, male or female, to pay one Sa' of dates or barley as Zakat-ul-Fitr}}
\hadithdefcmd{bukhari}{1505}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ قَالَ كُنَّا نُطْعِمُ الصَّدَقَةَ صَاعًا مِنْ شَعِيرٍ‏.‏\hadithno{1505}\hadithtrans{Narrated Abu Sa`id:We used to give one Sa' of barley as Sadaqat-ul-Fitr (per head)}}
\hadithdefcmd{bukhari}{1506}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ سَعْدِ بْنِ أَبِي سَرْحٍ الْعَامِرِيِّ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ يَقُولُ كُنَّا نُخْرِجُ زَكَاةَ الْفِطْرِ صَاعًا مِنْ طَعَامٍ، أَوْ صَاعًا مِنْ شَعِيرٍ، أَوْ صَاعًا مِنْ تَمْرٍ، أَوْ صَاعًا مِنْ أَقِطٍ، أَوْ صَاعًا مِنْ زَبِيبٍ‏.‏\hadithno{1506}\hadithtrans{Narrated Abu Sa`id Al-Khudri:We used to give one Sa' of meal or one Sa' of barley or one Sa' of dates, or one Sa' of cottage cheese or one Sa' of Raisins (dried grapes) as Zakat-ul-Fitr}}
\hadithdefcmd{bukhari}{1507}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ، قَالَ أَمَرَ النَّبِيُّ صلى الله عليه وسلم بِزَكَاةِ الْفِطْرِ، صَاعًا مِنْ تَمْرٍ، أَوْ صَاعًا مِنْ شَعِيرٍ‏.‏ قَالَ عَبْدُ اللَّهِ ـ رضى الله عنه ـ فَجَعَلَ النَّاسُ عِدْلَهُ مُدَّيْنِ مِنْ حِنْطَةٍ‏.‏\hadithno{1507}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) ordered (Muslims) to give one Sa' of dates or one Sa' of barley as Zakat-ul-Fitr. The people regarded two Mudds of wheat as equal to that}}
\hadithdefcmd{bukhari}{1508}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ يَزِيدَ الْعَدَنِيَّ، حَدَّثَنَا سُفْيَانُ، عَنْ زَيْدِ بْنِ أَسْلَمَ، قَالَ حَدَّثَنِي عِيَاضُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي سَرْحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ كُنَّا نُعْطِيهَا فِي زَمَانِ النَّبِيِّ صلى الله عليه وسلم صَاعًا مِنْ طَعَامٍ، أَوْ صَاعًا مِنْ تَمْرٍ، أَوْ صَاعًا مِنْ شَعِيرٍ، أَوْ صَاعًا مِنْ زَبِيبٍ، فَلَمَّا جَاءَ مُعَاوِيَةُ وَجَاءَتِ السَّمْرَاءُ قَالَ أُرَى مُدًّا مِنْ هَذَا يَعْدِلُ مُدَّيْنِ‏.‏\hadithno{1508}\hadithtrans{Narrated Abu Sa`id Al-Khudri:In the lifetime of the Prophet (ﷺ) we used to give one Sa' of food or one Sa' of dates or one Sa' of barley or one Sa' of Raisins (dried grapes) as Sadaqat-ul-Fitr. And when Muawiya became the Caliph and the wheat was (available in abundance) he said, "I think (observe) that one Mudd (of wheat) equals two Mudds (of any of the above mentioned things)}}
\hadithdefcmd{bukhari}{1509}{حَدَّثَنَا آدَمُ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ بِزَكَاةِ الْفِطْرِ قَبْلَ خُرُوجِ النَّاسِ إِلَى الصَّلاَةِ‏.‏\hadithno{1509}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) ordered the people to pay Zakat-ul-Fitr before going to the `Id prayer}}
\hadithdefcmd{bukhari}{1510}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا أَبُو عُمَرَ، عَنْ زَيْدٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ سَعْدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ كُنَّا نُخْرِجُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفِطْرِ صَاعًا مِنْ طَعَامٍ‏.‏ وَقَالَ أَبُو سَعِيدٍ وَكَانَ طَعَامَنَا الشَّعِيرُ وَالزَّبِيبُ وَالأَقِطُ وَالتَّمْرُ‏.‏\hadithno{1510}\hadithtrans{Narrated Abu Sa`id Al-Khudri:In the lifetime of Allah's Messenger (ﷺ) , we used to give one Sa' of food (edible things) as Sadaqat-ul-Fitr (to the poor). Our food used to be either of barley, raisins (dried grapes), cottage cheese or dates}}
\hadithdefcmd{bukhari}{1511}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ فَرَضَ النَّبِيُّ صلى الله عليه وسلم صَدَقَةَ الْفِطْرِ ـ أَوْ قَالَ رَمَضَانَ ـ عَلَى الذَّكَرِ وَالأُنْثَى، وَالْحُرِّ وَالْمَمْلُوكِ، صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ، فَعَدَلَ النَّاسُ بِهِ نِصْفَ صَاعٍ مِنْ بُرٍّ‏.‏ فَكَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يُعْطِي التَّمْرَ، فَأَعْوَزَ أَهْلُ الْمَدِينَةِ مِنَ التَّمْرِ فَأَعْطَى شَعِيرًا، فَكَانَ ابْنُ عُمَرَ يُعْطِي عَنِ الصَّغِيرِ وَالْكَبِيرِ، حَتَّى إِنْ كَانَ يُعْطِي عَنْ بَنِيَّ، وَكَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يُعْطِيهَا الَّذِينَ يَقْبَلُونَهَا، وَكَانُوا يُعْطُونَ قَبْلَ الْفِطْرِ بِيَوْمٍ أَوْ يَوْمَيْنِ‏.‏\hadithno{1511}\hadithtrans{Narrated Nafi`:Ibn `Umar said, "The Prophet (ﷺ) made incumbent on every male or female, free man or slave, the payment of one Sa' of dates or barley as Sadaqat-ul-Fitr (or said Sadaqa-Ramadan)." The people then substituted half Sa' of wheat for that. Ibn `Umar used to give dates (as Sadaqat-ul-Fitr). Once there was scarcity of dates in Medina and Ibn `Umar gave barley. 'And Ibn `Umar used to give Sadaqat-ul- Fitr for every young and old person. He even used to give on behalf of my children. Ibn `Umar used to give Sadaqat-ul-Fitr to those who had been officially appointed for its collection. People used to give Sadaqat-ul-Fitr (even) a day or two before the `Id}}
\hadithdefcmd{bukhari}{1512}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنه ـ قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَدَقَةَ الْفِطْرِ صَاعًا مِنْ شَعِيرٍ، أَوْ صَاعًا مِنْ تَمْرٍ عَلَى الصَّغِيرِ وَالْكَبِيرِ وَالْحُرِّ وَالْمَمْلُوكِ‏.‏\hadithno{1512}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) has made Sadaqat-ul-Fitr obligatory, (and it was), either one Sa' of barley or one Sa' of dates (and its payment was obligatory) on young and old people, and on free men as well as on slaves}}
